
types={
'Thing': ('Thing', 'pydantic_schemaorg.Thing', 'Thing'),
'Organization': ('Organization', 'pydantic_schemaorg.Organization', 'Organization'),
'NewsMediaOrganization': ('NewsMediaOrganization', 'pydantic_schemaorg.NewsMediaOrganization', 'NewsMediaOrganization'),
'Action': ('Action', 'pydantic_schemaorg.Action', 'Action'),
'OrganizeAction': ('OrganizeAction', 'pydantic_schemaorg.OrganizeAction', 'OrganizeAction'),
'PlanAction': ('PlanAction', 'pydantic_schemaorg.PlanAction', 'PlanAction'),
'Intangible': ('Intangible', 'pydantic_schemaorg.Intangible', 'Intangible'),
'Enumeration': ('Enumeration', 'pydantic_schemaorg.Enumeration', 'Enumeration'),
'NonprofitType': ('NonprofitType', 'pydantic_schemaorg.NonprofitType', 'NonprofitType'),
'USNonprofitType': ('USNonprofitType', 'pydantic_schemaorg.USNonprofitType', 'USNonprofitType'),
'Nonprofit501c2': ('Nonprofit501c2', 'pydantic_schemaorg.Nonprofit501c2', 'Nonprofit501c2'),
'StatusEnumeration': ('StatusEnumeration', 'pydantic_schemaorg.StatusEnumeration', 'StatusEnumeration'),
'EventStatusType': ('EventStatusType', 'pydantic_schemaorg.EventStatusType', 'EventStatusType'),
'EventCancelled': ('EventCancelled', 'pydantic_schemaorg.EventCancelled', 'EventCancelled'),
'MeasurementTypeEnumeration': ('MeasurementTypeEnumeration', 'pydantic_schemaorg.MeasurementTypeEnumeration', 'MeasurementTypeEnumeration'),
'BodyMeasurementTypeEnumeration': ('BodyMeasurementTypeEnumeration', 'pydantic_schemaorg.BodyMeasurementTypeEnumeration', 'BodyMeasurementTypeEnumeration'),
'BodyMeasurementHead': ('BodyMeasurementHead', 'pydantic_schemaorg.BodyMeasurementHead', 'BodyMeasurementHead'),
'ConsumeAction': ('ConsumeAction', 'pydantic_schemaorg.ConsumeAction', 'ConsumeAction'),
'ListenAction': ('ListenAction', 'pydantic_schemaorg.ListenAction', 'ListenAction'),
'TradeAction': ('TradeAction', 'pydantic_schemaorg.TradeAction', 'TradeAction'),
'MedicalEnumeration': ('MedicalEnumeration', 'pydantic_schemaorg.MedicalEnumeration', 'MedicalEnumeration'),
'Specialty': ('Specialty', 'pydantic_schemaorg.Specialty', 'Specialty'),
'MedicalSpecialty': ('MedicalSpecialty', 'pydantic_schemaorg.MedicalSpecialty', 'MedicalSpecialty'),
'Urologic': ('Urologic', 'pydantic_schemaorg.Urologic', 'Urologic'),
'CreativeWork': ('CreativeWork', 'pydantic_schemaorg.CreativeWork', 'CreativeWork'),
'DigitalDocument': ('DigitalDocument', 'pydantic_schemaorg.DigitalDocument', 'DigitalDocument'),
'PresentationDigitalDocument': ('PresentationDigitalDocument', 'pydantic_schemaorg.PresentationDigitalDocument', 'PresentationDigitalDocument'),
'MedicineSystem': ('MedicineSystem', 'pydantic_schemaorg.MedicineSystem', 'MedicineSystem'),
'Chiropractic': ('Chiropractic', 'pydantic_schemaorg.Chiropractic', 'Chiropractic'),
'Reservation': ('Reservation', 'pydantic_schemaorg.Reservation', 'Reservation'),
'Anesthesia': ('Anesthesia', 'pydantic_schemaorg.Anesthesia', 'Anesthesia'),
'WearableMeasurementTypeEnumeration': ('WearableMeasurementTypeEnumeration', 'pydantic_schemaorg.WearableMeasurementTypeEnumeration', 'WearableMeasurementTypeEnumeration'),
'WearableMeasurementHips': ('WearableMeasurementHips', 'pydantic_schemaorg.WearableMeasurementHips', 'WearableMeasurementHips'),
'AlignmentObject': ('AlignmentObject', 'pydantic_schemaorg.AlignmentObject', 'AlignmentObject'),
'Place': ('Place', 'pydantic_schemaorg.Place', 'Place'),
'LocalBusiness': ('LocalBusiness', 'pydantic_schemaorg.LocalBusiness', 'LocalBusiness'),
'LodgingBusiness': ('LodgingBusiness', 'pydantic_schemaorg.LodgingBusiness', 'LodgingBusiness'),
'BedAndBreakfast': ('BedAndBreakfast', 'pydantic_schemaorg.BedAndBreakfast', 'BedAndBreakfast'),
'Audience': ('Audience', 'pydantic_schemaorg.Audience', 'Audience'),
'BusinessAudience': ('BusinessAudience', 'pydantic_schemaorg.BusinessAudience', 'BusinessAudience'),
'InteractAction': ('InteractAction', 'pydantic_schemaorg.InteractAction', 'InteractAction'),
'JoinAction': ('JoinAction', 'pydantic_schemaorg.JoinAction', 'JoinAction'),
'MedicalEntity': ('MedicalEntity', 'pydantic_schemaorg.MedicalEntity', 'MedicalEntity'),
'MedicalTest': ('MedicalTest', 'pydantic_schemaorg.MedicalTest', 'MedicalTest'),
'Person': ('Person', 'pydantic_schemaorg.Person', 'Person'),
'BodyMeasurementBust': ('BodyMeasurementBust', 'pydantic_schemaorg.BodyMeasurementBust', 'BodyMeasurementBust'),
'MedicalIntangible': ('MedicalIntangible', 'pydantic_schemaorg.MedicalIntangible', 'MedicalIntangible'),
'DefinedTerm': ('DefinedTerm', 'pydantic_schemaorg.DefinedTerm', 'DefinedTerm'),
'CategoryCode': ('CategoryCode', 'pydantic_schemaorg.CategoryCode', 'CategoryCode'),
'MedicalCode': ('MedicalCode', 'pydantic_schemaorg.MedicalCode', 'MedicalCode'),
'Musculoskeletal': ('Musculoskeletal', 'pydantic_schemaorg.Musculoskeletal', 'Musculoskeletal'),
'MusicAlbumReleaseType': ('MusicAlbumReleaseType', 'pydantic_schemaorg.MusicAlbumReleaseType', 'MusicAlbumReleaseType'),
'BroadcastRelease': ('BroadcastRelease', 'pydantic_schemaorg.BroadcastRelease', 'BroadcastRelease'),
'HomeAndConstructionBusiness': ('HomeAndConstructionBusiness', 'pydantic_schemaorg.HomeAndConstructionBusiness', 'HomeAndConstructionBusiness'),
'Electrician': ('Electrician', 'pydantic_schemaorg.Electrician', 'Electrician'),
'BodyMeasurementWaist': ('BodyMeasurementWaist', 'pydantic_schemaorg.BodyMeasurementWaist', 'BodyMeasurementWaist'),
'PhysicalActivityCategory': ('PhysicalActivityCategory', 'pydantic_schemaorg.PhysicalActivityCategory', 'PhysicalActivityCategory'),
'LeisureTimeActivity': ('LeisureTimeActivity', 'pydantic_schemaorg.LeisureTimeActivity', 'LeisureTimeActivity'),
'MedicalBusiness': ('MedicalBusiness', 'pydantic_schemaorg.MedicalBusiness', 'MedicalBusiness'),
'Podiatric': ('Podiatric', 'pydantic_schemaorg.Podiatric', 'Podiatric'),
'CancelAction': ('CancelAction', 'pydantic_schemaorg.CancelAction', 'CancelAction'),
'MedicalStudyStatus': ('MedicalStudyStatus', 'pydantic_schemaorg.MedicalStudyStatus', 'MedicalStudyStatus'),
'NotYetRecruiting': ('NotYetRecruiting', 'pydantic_schemaorg.NotYetRecruiting', 'NotYetRecruiting'),
'AllocateAction': ('AllocateAction', 'pydantic_schemaorg.AllocateAction', 'AllocateAction'),
'AssignAction': ('AssignAction', 'pydantic_schemaorg.AssignAction', 'AssignAction'),
'Review': ('Review', 'pydantic_schemaorg.Review', 'Review'),
'MediaReview': ('MediaReview', 'pydantic_schemaorg.MediaReview', 'MediaReview'),
'CivicStructure': ('CivicStructure', 'pydantic_schemaorg.CivicStructure', 'CivicStructure'),
'Airport': ('Airport', 'pydantic_schemaorg.Airport', 'Airport'),
'LearningResource': ('LearningResource', 'pydantic_schemaorg.LearningResource', 'LearningResource'),
'Quiz': ('Quiz', 'pydantic_schemaorg.Quiz', 'Quiz'),
'DrugCostCategory': ('DrugCostCategory', 'pydantic_schemaorg.DrugCostCategory', 'DrugCostCategory'),
'Retail': ('Retail', 'pydantic_schemaorg.Retail', 'Retail'),
'MedicalOrganization': ('MedicalOrganization', 'pydantic_schemaorg.MedicalOrganization', 'MedicalOrganization'),
'Dentist': ('Dentist', 'pydantic_schemaorg.Dentist', 'Dentist'),
'PlaceOfWorship': ('PlaceOfWorship', 'pydantic_schemaorg.PlaceOfWorship', 'PlaceOfWorship'),
'Synagogue': ('Synagogue', 'pydantic_schemaorg.Synagogue', 'Synagogue'),
'Order': ('Order', 'pydantic_schemaorg.Order', 'Order'),
'Store': ('Store', 'pydantic_schemaorg.Store', 'Store'),
'BikeStore': ('BikeStore', 'pydantic_schemaorg.BikeStore', 'BikeStore'),
'GovernmentBuilding': ('GovernmentBuilding', 'pydantic_schemaorg.GovernmentBuilding', 'GovernmentBuilding'),
'Embassy': ('Embassy', 'pydantic_schemaorg.Embassy', 'Embassy'),
'OccupationalActivity': ('OccupationalActivity', 'pydantic_schemaorg.OccupationalActivity', 'OccupationalActivity'),
'AssessAction': ('AssessAction', 'pydantic_schemaorg.AssessAction', 'AssessAction'),
'ChooseAction': ('ChooseAction', 'pydantic_schemaorg.ChooseAction', 'ChooseAction'),
'Product': ('Product', 'pydantic_schemaorg.Product', 'Product'),
'SomeProducts': ('SomeProducts', 'pydantic_schemaorg.SomeProducts', 'SomeProducts'),
'Nonprofit501c5': ('Nonprofit501c5', 'pydantic_schemaorg.Nonprofit501c5', 'Nonprofit501c5'),
'GamePlayMode': ('GamePlayMode', 'pydantic_schemaorg.GamePlayMode', 'GamePlayMode'),
'PriceComponentTypeEnumeration': ('PriceComponentTypeEnumeration', 'pydantic_schemaorg.PriceComponentTypeEnumeration', 'PriceComponentTypeEnumeration'),
'DistanceFee': ('DistanceFee', 'pydantic_schemaorg.DistanceFee', 'DistanceFee'),
'MediaReviewItem': ('MediaReviewItem', 'pydantic_schemaorg.MediaReviewItem', 'MediaReviewItem'),
'HealthAspectEnumeration': ('HealthAspectEnumeration', 'pydantic_schemaorg.HealthAspectEnumeration', 'HealthAspectEnumeration'),
'BenefitsHealthAspect': ('BenefitsHealthAspect', 'pydantic_schemaorg.BenefitsHealthAspect', 'BenefitsHealthAspect'),
'OfferItemCondition': ('OfferItemCondition', 'pydantic_schemaorg.OfferItemCondition', 'OfferItemCondition'),
'NewCondition': ('NewCondition', 'pydantic_schemaorg.NewCondition', 'NewCondition'),
'MedicalProcedure': ('MedicalProcedure', 'pydantic_schemaorg.MedicalProcedure', 'MedicalProcedure'),
'PhysicalExam': ('PhysicalExam', 'pydantic_schemaorg.PhysicalExam', 'PhysicalExam'),
'Nose': ('Nose', 'pydantic_schemaorg.Nose', 'Nose'),
'Head': ('Head', 'pydantic_schemaorg.Head', 'Head'),
'BookmarkAction': ('BookmarkAction', 'pydantic_schemaorg.BookmarkAction', 'BookmarkAction'),
'ReturnLabelSourceEnumeration': ('ReturnLabelSourceEnumeration', 'pydantic_schemaorg.ReturnLabelSourceEnumeration', 'ReturnLabelSourceEnumeration'),
'ReturnLabelDownloadAndPrint': ('ReturnLabelDownloadAndPrint', 'pydantic_schemaorg.ReturnLabelDownloadAndPrint', 'ReturnLabelDownloadAndPrint'),
'DayOfWeek': ('DayOfWeek', 'pydantic_schemaorg.DayOfWeek', 'DayOfWeek'),
'Saturday': ('Saturday', 'pydantic_schemaorg.Saturday', 'Saturday'),
'Nonprofit501c18': ('Nonprofit501c18', 'pydantic_schemaorg.Nonprofit501c18', 'Nonprofit501c18'),
'GameServerStatus': ('GameServerStatus', 'pydantic_schemaorg.GameServerStatus', 'GameServerStatus'),
'OfflineTemporarily': ('OfflineTemporarily', 'pydantic_schemaorg.OfflineTemporarily', 'OfflineTemporarily'),
'Zoo': ('Zoo', 'pydantic_schemaorg.Zoo', 'Zoo'),
'LegalValueLevel': ('LegalValueLevel', 'pydantic_schemaorg.LegalValueLevel', 'LegalValueLevel'),
'Series': ('Series', 'pydantic_schemaorg.Series', 'Series'),
'CreativeWorkSeries': ('CreativeWorkSeries', 'pydantic_schemaorg.CreativeWorkSeries', 'CreativeWorkSeries'),
'BookSeries': ('BookSeries', 'pydantic_schemaorg.BookSeries', 'BookSeries'),
'BodyMeasurementInsideLeg': ('BodyMeasurementInsideLeg', 'pydantic_schemaorg.BodyMeasurementInsideLeg', 'BodyMeasurementInsideLeg'),
'Park': ('Park', 'pydantic_schemaorg.Park', 'Park'),
'UKNonprofitType': ('UKNonprofitType', 'pydantic_schemaorg.UKNonprofitType', 'UKNonprofitType'),
'UnincorporatedAssociationCharity': ('UnincorporatedAssociationCharity', 'pydantic_schemaorg.UnincorporatedAssociationCharity', 'UnincorporatedAssociationCharity'),
'MapCategoryType': ('MapCategoryType', 'pydantic_schemaorg.MapCategoryType', 'MapCategoryType'),
'SeatingMap': ('SeatingMap', 'pydantic_schemaorg.SeatingMap', 'SeatingMap'),
'Nonprofit501f': ('Nonprofit501f', 'pydantic_schemaorg.Nonprofit501f', 'Nonprofit501f'),
'FoodEstablishment': ('FoodEstablishment', 'pydantic_schemaorg.FoodEstablishment', 'FoodEstablishment'),
'TransferAction': ('TransferAction', 'pydantic_schemaorg.TransferAction', 'TransferAction'),
'LendAction': ('LendAction', 'pydantic_schemaorg.LendAction', 'LendAction'),
'DrugCost': ('DrugCost', 'pydantic_schemaorg.DrugCost', 'DrugCost'),
'Demand': ('Demand', 'pydantic_schemaorg.Demand', 'Demand'),
'ItemAvailability': ('ItemAvailability', 'pydantic_schemaorg.ItemAvailability', 'ItemAvailability'),
'InStoreOnly': ('InStoreOnly', 'pydantic_schemaorg.InStoreOnly', 'InStoreOnly'),
'SportsActivityLocation': ('SportsActivityLocation', 'pydantic_schemaorg.SportsActivityLocation', 'SportsActivityLocation'),
'UserReview': ('UserReview', 'pydantic_schemaorg.UserReview', 'UserReview'),
'BusinessEntityType': ('BusinessEntityType', 'pydantic_schemaorg.BusinessEntityType', 'BusinessEntityType'),
'StructuredValue': ('StructuredValue', 'pydantic_schemaorg.StructuredValue', 'StructuredValue'),
'PropertyValue': ('PropertyValue', 'pydantic_schemaorg.PropertyValue', 'PropertyValue'),
'LocationFeatureSpecification': ('LocationFeatureSpecification', 'pydantic_schemaorg.LocationFeatureSpecification', 'LocationFeatureSpecification'),
'BookStore': ('BookStore', 'pydantic_schemaorg.BookStore', 'BookStore'),
'StagesHealthAspect': ('StagesHealthAspect', 'pydantic_schemaorg.StagesHealthAspect', 'StagesHealthAspect'),
'TherapeuticProcedure': ('TherapeuticProcedure', 'pydantic_schemaorg.TherapeuticProcedure', 'TherapeuticProcedure'),
'LegislativeBuilding': ('LegislativeBuilding', 'pydantic_schemaorg.LegislativeBuilding', 'LegislativeBuilding'),
'WebPage': ('WebPage', 'pydantic_schemaorg.WebPage', 'WebPage'),
'SizeSystemEnumeration': ('SizeSystemEnumeration', 'pydantic_schemaorg.SizeSystemEnumeration', 'SizeSystemEnumeration'),
'SizeSystemMetric': ('SizeSystemMetric', 'pydantic_schemaorg.SizeSystemMetric', 'SizeSystemMetric'),
'RestrictedDiet': ('RestrictedDiet', 'pydantic_schemaorg.RestrictedDiet', 'RestrictedDiet'),
'LowLactoseDiet': ('LowLactoseDiet', 'pydantic_schemaorg.LowLactoseDiet', 'LowLactoseDiet'),
'Statement': ('Statement', 'pydantic_schemaorg.Statement', 'Statement'),
'MedicalImagingTechnique': ('MedicalImagingTechnique', 'pydantic_schemaorg.MedicalImagingTechnique', 'MedicalImagingTechnique'),
'XRay': ('XRay', 'pydantic_schemaorg.XRay', 'XRay'),
'PaymentStatusType': ('PaymentStatusType', 'pydantic_schemaorg.PaymentStatusType', 'PaymentStatusType'),
'PaymentPastDue': ('PaymentPastDue', 'pydantic_schemaorg.PaymentPastDue', 'PaymentPastDue'),
'SelfCareHealthAspect': ('SelfCareHealthAspect', 'pydantic_schemaorg.SelfCareHealthAspect', 'SelfCareHealthAspect'),
'Clip': ('Clip', 'pydantic_schemaorg.Clip', 'Clip'),
'SizeGroupEnumeration': ('SizeGroupEnumeration', 'pydantic_schemaorg.SizeGroupEnumeration', 'SizeGroupEnumeration'),
'WearableSizeGroupEnumeration': ('WearableSizeGroupEnumeration', 'pydantic_schemaorg.WearableSizeGroupEnumeration', 'WearableSizeGroupEnumeration'),
'WearableSizeGroupPlus': ('WearableSizeGroupPlus', 'pydantic_schemaorg.WearableSizeGroupPlus', 'WearableSizeGroupPlus'),
'SideEffectsHealthAspect': ('SideEffectsHealthAspect', 'pydantic_schemaorg.SideEffectsHealthAspect', 'SideEffectsHealthAspect'),
'Accommodation': ('Accommodation', 'pydantic_schemaorg.Accommodation', 'Accommodation'),
'Room': ('Room', 'pydantic_schemaorg.Room', 'Room'),
'VideoGameSeries': ('VideoGameSeries', 'pydantic_schemaorg.VideoGameSeries', 'VideoGameSeries'),
'StrengthTraining': ('StrengthTraining', 'pydantic_schemaorg.StrengthTraining', 'StrengthTraining'),
'OccupationalExperienceRequirements': ('OccupationalExperienceRequirements', 'pydantic_schemaorg.OccupationalExperienceRequirements', 'OccupationalExperienceRequirements'),
'SpeechPathology': ('SpeechPathology', 'pydantic_schemaorg.SpeechPathology', 'SpeechPathology'),
'BioChemEntity': ('BioChemEntity', 'pydantic_schemaorg.BioChemEntity', 'BioChemEntity'),
'MolecularEntity': ('MolecularEntity', 'pydantic_schemaorg.MolecularEntity', 'MolecularEntity'),
'Gastroenterologic': ('Gastroenterologic', 'pydantic_schemaorg.Gastroenterologic', 'Gastroenterologic'),
'WearableMeasurementBack': ('WearableMeasurementBack', 'pydantic_schemaorg.WearableMeasurementBack', 'WearableMeasurementBack'),
'ReimbursementCap': ('ReimbursementCap', 'pydantic_schemaorg.ReimbursementCap', 'ReimbursementCap'),
'GovernmentBenefitsType': ('GovernmentBenefitsType', 'pydantic_schemaorg.GovernmentBenefitsType', 'GovernmentBenefitsType'),
'BusinessSupport': ('BusinessSupport', 'pydantic_schemaorg.BusinessSupport', 'BusinessSupport'),
'ActivationFee': ('ActivationFee', 'pydantic_schemaorg.ActivationFee', 'ActivationFee'),
'Comment': ('Comment', 'pydantic_schemaorg.Comment', 'Comment'),
'CorrectionComment': ('CorrectionComment', 'pydantic_schemaorg.CorrectionComment', 'CorrectionComment'),
'ReturnMethodEnumeration': ('ReturnMethodEnumeration', 'pydantic_schemaorg.ReturnMethodEnumeration', 'ReturnMethodEnumeration'),
'Residence': ('Residence', 'pydantic_schemaorg.Residence', 'Residence'),
'Manuscript': ('Manuscript', 'pydantic_schemaorg.Manuscript', 'Manuscript'),
'WebPageElement': ('WebPageElement', 'pydantic_schemaorg.WebPageElement', 'WebPageElement'),
'SiteNavigationElement': ('SiteNavigationElement', 'pydantic_schemaorg.SiteNavigationElement', 'SiteNavigationElement'),
'SheetMusic': ('SheetMusic', 'pydantic_schemaorg.SheetMusic', 'SheetMusic'),
'RsvpResponseType': ('RsvpResponseType', 'pydantic_schemaorg.RsvpResponseType', 'RsvpResponseType'),
'RsvpResponseNo': ('RsvpResponseNo', 'pydantic_schemaorg.RsvpResponseNo', 'RsvpResponseNo'),
'Class': ('Class', 'pydantic_schemaorg.Class', 'Class'),
'DataType': ('DataType', 'pydantic_schemaorg.DataType', 'DataType'),
'AutomotiveBusiness': ('AutomotiveBusiness', 'pydantic_schemaorg.AutomotiveBusiness', 'AutomotiveBusiness'),
'AutoPartsStore': ('AutoPartsStore', 'pydantic_schemaorg.AutoPartsStore', 'AutoPartsStore'),
'Episode': ('Episode', 'pydantic_schemaorg.Episode', 'Episode'),
'RadioEpisode': ('RadioEpisode', 'pydantic_schemaorg.RadioEpisode', 'RadioEpisode'),
'Season': ('Season', 'pydantic_schemaorg.Season', 'Season'),
'HalalDiet': ('HalalDiet', 'pydantic_schemaorg.HalalDiet', 'HalalDiet'),
'HealthAndBeautyBusiness': ('HealthAndBeautyBusiness', 'pydantic_schemaorg.HealthAndBeautyBusiness', 'HealthAndBeautyBusiness'),
'DaySpa': ('DaySpa', 'pydantic_schemaorg.DaySpa', 'DaySpa'),
'Article': ('Article', 'pydantic_schemaorg.Article', 'Article'),
'NewsArticle': ('NewsArticle', 'pydantic_schemaorg.NewsArticle', 'NewsArticle'),
'AnalysisNewsArticle': ('AnalysisNewsArticle', 'pydantic_schemaorg.AnalysisNewsArticle', 'AnalysisNewsArticle'),
'MusicAlbumProductionType': ('MusicAlbumProductionType', 'pydantic_schemaorg.MusicAlbumProductionType', 'MusicAlbumProductionType'),
'StudioAlbum': ('StudioAlbum', 'pydantic_schemaorg.StudioAlbum', 'StudioAlbum'),
'ReturnFeesEnumeration': ('ReturnFeesEnumeration', 'pydantic_schemaorg.ReturnFeesEnumeration', 'ReturnFeesEnumeration'),
'ReturnShippingFees': ('ReturnShippingFees', 'pydantic_schemaorg.ReturnShippingFees', 'ReturnShippingFees'),
'Quantity': ('Quantity', 'pydantic_schemaorg.Quantity', 'Quantity'),
'Energy': ('Energy', 'pydantic_schemaorg.Energy', 'Energy'),
'ControlAction': ('ControlAction', 'pydantic_schemaorg.ControlAction', 'ControlAction'),
'DeactivateAction': ('DeactivateAction', 'pydantic_schemaorg.DeactivateAction', 'DeactivateAction'),
'MusicPlaylist': ('MusicPlaylist', 'pydantic_schemaorg.MusicPlaylist', 'MusicPlaylist'),
'MusicAlbum': ('MusicAlbum', 'pydantic_schemaorg.MusicAlbum', 'MusicAlbum'),
'MoveAction': ('MoveAction', 'pydantic_schemaorg.MoveAction', 'MoveAction'),
'TravelAction': ('TravelAction', 'pydantic_schemaorg.TravelAction', 'TravelAction'),
'Permit': ('Permit', 'pydantic_schemaorg.Permit', 'Permit'),
'Gynecologic': ('Gynecologic', 'pydantic_schemaorg.Gynecologic', 'Gynecologic'),
'EffectivenessHealthAspect': ('EffectivenessHealthAspect', 'pydantic_schemaorg.EffectivenessHealthAspect', 'EffectivenessHealthAspect'),
'WholesaleStore': ('WholesaleStore', 'pydantic_schemaorg.WholesaleStore', 'WholesaleStore'),
'FundingScheme': ('FundingScheme', 'pydantic_schemaorg.FundingScheme', 'FundingScheme'),
'Recommendation': ('Recommendation', 'pydantic_schemaorg.Recommendation', 'Recommendation'),
'MedicalAudienceType': ('MedicalAudienceType', 'pydantic_schemaorg.MedicalAudienceType', 'MedicalAudienceType'),
'Clinician': ('Clinician', 'pydantic_schemaorg.Clinician', 'Clinician'),
'MarryAction': ('MarryAction', 'pydantic_schemaorg.MarryAction', 'MarryAction'),
'MediaObject': ('MediaObject', 'pydantic_schemaorg.MediaObject', 'MediaObject'),
'DataDownload': ('DataDownload', 'pydantic_schemaorg.DataDownload', 'DataDownload'),
'BoatReservation': ('BoatReservation', 'pydantic_schemaorg.BoatReservation', 'BoatReservation'),
'HinduTemple': ('HinduTemple', 'pydantic_schemaorg.HinduTemple', 'HinduTemple'),
'MedicalDevicePurpose': ('MedicalDevicePurpose', 'pydantic_schemaorg.MedicalDevicePurpose', 'MedicalDevicePurpose'),
'Diagnostic': ('Diagnostic', 'pydantic_schemaorg.Diagnostic', 'Diagnostic'),
'AnatomicalStructure': ('AnatomicalStructure', 'pydantic_schemaorg.AnatomicalStructure', 'AnatomicalStructure'),
'Nerve': ('Nerve', 'pydantic_schemaorg.Nerve', 'Nerve'),
'CarUsageType': ('CarUsageType', 'pydantic_schemaorg.CarUsageType', 'CarUsageType'),
'DrivingSchoolVehicleUsage': ('DrivingSchoolVehicleUsage', 'pydantic_schemaorg.DrivingSchoolVehicleUsage', 'DrivingSchoolVehicleUsage'),
'TelevisionStation': ('TelevisionStation', 'pydantic_schemaorg.TelevisionStation', 'TelevisionStation'),
'Osteopathic': ('Osteopathic', 'pydantic_schemaorg.Osteopathic', 'Osteopathic'),
'WearableSizeGroupMens': ('WearableSizeGroupMens', 'pydantic_schemaorg.WearableSizeGroupMens', 'WearableSizeGroupMens'),
'CollectionPage': ('CollectionPage', 'pydantic_schemaorg.CollectionPage', 'CollectionPage'),
'Question': ('Question', 'pydantic_schemaorg.Question', 'Question'),
'Substance': ('Substance', 'pydantic_schemaorg.Substance', 'Substance'),
'OnlineOnly': ('OnlineOnly', 'pydantic_schemaorg.OnlineOnly', 'OnlineOnly'),
'GasStation': ('GasStation', 'pydantic_schemaorg.GasStation', 'GasStation'),
'Pediatric': ('Pediatric', 'pydantic_schemaorg.Pediatric', 'Pediatric'),
'MedicalEvidenceLevel': ('MedicalEvidenceLevel', 'pydantic_schemaorg.MedicalEvidenceLevel', 'MedicalEvidenceLevel'),
'EvidenceLevelC': ('EvidenceLevelC', 'pydantic_schemaorg.EvidenceLevelC', 'EvidenceLevelC'),
'MultiPlayer': ('MultiPlayer', 'pydantic_schemaorg.MultiPlayer', 'MultiPlayer'),
'ItemListOrderType': ('ItemListOrderType', 'pydantic_schemaorg.ItemListOrderType', 'ItemListOrderType'),
'ItemListUnordered': ('ItemListUnordered', 'pydantic_schemaorg.ItemListUnordered', 'ItemListUnordered'),
'Message': ('Message', 'pydantic_schemaorg.Message', 'Message'),
'TennisComplex': ('TennisComplex', 'pydantic_schemaorg.TennisComplex', 'TennisComplex'),
'MedicalContraindication': ('MedicalContraindication', 'pydantic_schemaorg.MedicalContraindication', 'MedicalContraindication'),
'MediaGallery': ('MediaGallery', 'pydantic_schemaorg.MediaGallery', 'MediaGallery'),
'RegisterAction': ('RegisterAction', 'pydantic_schemaorg.RegisterAction', 'RegisterAction'),
'AmpStory': ('AmpStory', 'pydantic_schemaorg.AmpStory', 'AmpStory'),
'LifestyleModification': ('LifestyleModification', 'pydantic_schemaorg.LifestyleModification', 'LifestyleModification'),
'PhysicalActivity': ('PhysicalActivity', 'pydantic_schemaorg.PhysicalActivity', 'PhysicalActivity'),
'ExercisePlan': ('ExercisePlan', 'pydantic_schemaorg.ExercisePlan', 'ExercisePlan'),
'ChildCare': ('ChildCare', 'pydantic_schemaorg.ChildCare', 'ChildCare'),
'MediaManipulationRatingEnumeration': ('MediaManipulationRatingEnumeration', 'pydantic_schemaorg.MediaManipulationRatingEnumeration', 'MediaManipulationRatingEnumeration'),
'EntertainmentBusiness': ('EntertainmentBusiness', 'pydantic_schemaorg.EntertainmentBusiness', 'EntertainmentBusiness'),
'ComedyClub': ('ComedyClub', 'pydantic_schemaorg.ComedyClub', 'ComedyClub'),
'SendAction': ('SendAction', 'pydantic_schemaorg.SendAction', 'SendAction'),
'Thesis': ('Thesis', 'pydantic_schemaorg.Thesis', 'Thesis'),
'ShortStory': ('ShortStory', 'pydantic_schemaorg.ShortStory', 'ShortStory'),
'ScheduleAction': ('ScheduleAction', 'pydantic_schemaorg.ScheduleAction', 'ScheduleAction'),
'Ayurvedic': ('Ayurvedic', 'pydantic_schemaorg.Ayurvedic', 'Ayurvedic'),
'Nonprofit501c26': ('Nonprofit501c26', 'pydantic_schemaorg.Nonprofit501c26', 'Nonprofit501c26'),
'MedicalTherapy': ('MedicalTherapy', 'pydantic_schemaorg.MedicalTherapy', 'MedicalTherapy'),
'RadiationTherapy': ('RadiationTherapy', 'pydantic_schemaorg.RadiationTherapy', 'RadiationTherapy'),
'EnergyEfficiencyEnumeration': ('EnergyEfficiencyEnumeration', 'pydantic_schemaorg.EnergyEfficiencyEnumeration', 'EnergyEfficiencyEnumeration'),
'EUEnergyEfficiencyEnumeration': ('EUEnergyEfficiencyEnumeration', 'pydantic_schemaorg.EUEnergyEfficiencyEnumeration', 'EUEnergyEfficiencyEnumeration'),
'FindAction': ('FindAction', 'pydantic_schemaorg.FindAction', 'FindAction'),
'DiscoverAction': ('DiscoverAction', 'pydantic_schemaorg.DiscoverAction', 'DiscoverAction'),
'Monday': ('Monday', 'pydantic_schemaorg.Monday', 'Monday'),
'DoseSchedule': ('DoseSchedule', 'pydantic_schemaorg.DoseSchedule', 'DoseSchedule'),
'RecommendedDoseSchedule': ('RecommendedDoseSchedule', 'pydantic_schemaorg.RecommendedDoseSchedule', 'RecommendedDoseSchedule'),
'LegalForceStatus': ('LegalForceStatus', 'pydantic_schemaorg.LegalForceStatus', 'LegalForceStatus'),
'PartiallyInForce': ('PartiallyInForce', 'pydantic_schemaorg.PartiallyInForce', 'PartiallyInForce'),
'FinancialService': ('FinancialService', 'pydantic_schemaorg.FinancialService', 'FinancialService'),
'BankOrCreditUnion': ('BankOrCreditUnion', 'pydantic_schemaorg.BankOrCreditUnion', 'BankOrCreditUnion'),
'MedicalCondition': ('MedicalCondition', 'pydantic_schemaorg.MedicalCondition', 'MedicalCondition'),
'MedicalSignOrSymptom': ('MedicalSignOrSymptom', 'pydantic_schemaorg.MedicalSignOrSymptom', 'MedicalSignOrSymptom'),
'MedicalSymptom': ('MedicalSymptom', 'pydantic_schemaorg.MedicalSymptom', 'MedicalSymptom'),
'MathSolver': ('MathSolver', 'pydantic_schemaorg.MathSolver', 'MathSolver'),
'ReturnFeesCustomerResponsibility': ('ReturnFeesCustomerResponsibility', 'pydantic_schemaorg.ReturnFeesCustomerResponsibility', 'ReturnFeesCustomerResponsibility'),
'MusicReleaseFormatType': ('MusicReleaseFormatType', 'pydantic_schemaorg.MusicReleaseFormatType', 'MusicReleaseFormatType'),
'VinylFormat': ('VinylFormat', 'pydantic_schemaorg.VinylFormat', 'VinylFormat'),
'DigitalAudioTapeFormat': ('DigitalAudioTapeFormat', 'pydantic_schemaorg.DigitalAudioTapeFormat', 'DigitalAudioTapeFormat'),
'MedicalSign': ('MedicalSign', 'pydantic_schemaorg.MedicalSign', 'MedicalSign'),
'BodyMeasurementWeight': ('BodyMeasurementWeight', 'pydantic_schemaorg.BodyMeasurementWeight', 'BodyMeasurementWeight'),
'Mass': ('Mass', 'pydantic_schemaorg.Mass', 'Mass'),
'Service': ('Service', 'pydantic_schemaorg.Service', 'Service'),
'FinancialProduct': ('FinancialProduct', 'pydantic_schemaorg.FinancialProduct', 'FinancialProduct'),
'SoftwareApplication': ('SoftwareApplication', 'pydantic_schemaorg.SoftwareApplication', 'SoftwareApplication'),
'WearableSizeSystemEnumeration': ('WearableSizeSystemEnumeration', 'pydantic_schemaorg.WearableSizeSystemEnumeration', 'WearableSizeSystemEnumeration'),
'Flexibility': ('Flexibility', 'pydantic_schemaorg.Flexibility', 'Flexibility'),
'PalliativeProcedure': ('PalliativeProcedure', 'pydantic_schemaorg.PalliativeProcedure', 'PalliativeProcedure'),
'TravelAgency': ('TravelAgency', 'pydantic_schemaorg.TravelAgency', 'TravelAgency'),
'RecyclingCenter': ('RecyclingCenter', 'pydantic_schemaorg.RecyclingCenter', 'RecyclingCenter'),
'TaxiReservation': ('TaxiReservation', 'pydantic_schemaorg.TaxiReservation', 'TaxiReservation'),
'VisualArtwork': ('VisualArtwork', 'pydantic_schemaorg.VisualArtwork', 'VisualArtwork'),
'CoverArt': ('CoverArt', 'pydantic_schemaorg.CoverArt', 'CoverArt'),
'ComicStory': ('ComicStory', 'pydantic_schemaorg.ComicStory', 'ComicStory'),
'ComicCoverArt': ('ComicCoverArt', 'pydantic_schemaorg.ComicCoverArt', 'ComicCoverArt'),
'ProductModel': ('ProductModel', 'pydantic_schemaorg.ProductModel', 'ProductModel'),
'WearableSizeSystemContinental': ('WearableSizeSystemContinental', 'pydantic_schemaorg.WearableSizeSystemContinental', 'WearableSizeSystemContinental'),
'DietNutrition': ('DietNutrition', 'pydantic_schemaorg.DietNutrition', 'DietNutrition'),
'DeliveryMethod': ('DeliveryMethod', 'pydantic_schemaorg.DeliveryMethod', 'DeliveryMethod'),
'MerchantReturnPolicy': ('MerchantReturnPolicy', 'pydantic_schemaorg.MerchantReturnPolicy', 'MerchantReturnPolicy'),
'DigitalDocumentPermissionType': ('DigitalDocumentPermissionType', 'pydantic_schemaorg.DigitalDocumentPermissionType', 'DigitalDocumentPermissionType'),
'WritePermission': ('WritePermission', 'pydantic_schemaorg.WritePermission', 'WritePermission'),
'Apartment': ('Apartment', 'pydantic_schemaorg.Apartment', 'Apartment'),
'MedicalStudy': ('MedicalStudy', 'pydantic_schemaorg.MedicalStudy', 'MedicalStudy'),
'MedicalObservationalStudy': ('MedicalObservationalStudy', 'pydantic_schemaorg.MedicalObservationalStudy', 'MedicalObservationalStudy'),
'BowlingAlley': ('BowlingAlley', 'pydantic_schemaorg.BowlingAlley', 'BowlingAlley'),
'PriceSpecification': ('PriceSpecification', 'pydantic_schemaorg.PriceSpecification', 'PriceSpecification'),
'MayTreatHealthAspect': ('MayTreatHealthAspect', 'pydantic_schemaorg.MayTreatHealthAspect', 'MayTreatHealthAspect'),
'PayAction': ('PayAction', 'pydantic_schemaorg.PayAction', 'PayAction'),
'DrugPregnancyCategory': ('DrugPregnancyCategory', 'pydantic_schemaorg.DrugPregnancyCategory', 'DrugPregnancyCategory'),
'FDAcategoryX': ('FDAcategoryX', 'pydantic_schemaorg.FDAcategoryX', 'FDAcategoryX'),
'DiabeticDiet': ('DiabeticDiet', 'pydantic_schemaorg.DiabeticDiet', 'DiabeticDiet'),
'HinduDiet': ('HinduDiet', 'pydantic_schemaorg.HinduDiet', 'HinduDiet'),
'CommunicateAction': ('CommunicateAction', 'pydantic_schemaorg.CommunicateAction', 'CommunicateAction'),
'InformAction': ('InformAction', 'pydantic_schemaorg.InformAction', 'InformAction'),
'ConfirmAction': ('ConfirmAction', 'pydantic_schemaorg.ConfirmAction', 'ConfirmAction'),
'DefinedRegion': ('DefinedRegion', 'pydantic_schemaorg.DefinedRegion', 'DefinedRegion'),
'EnergyStarEnergyEfficiencyEnumeration': ('EnergyStarEnergyEfficiencyEnumeration', 'pydantic_schemaorg.EnergyStarEnergyEfficiencyEnumeration', 'EnergyStarEnergyEfficiencyEnumeration'),
'PerformingArtsTheater': ('PerformingArtsTheater', 'pydantic_schemaorg.PerformingArtsTheater', 'PerformingArtsTheater'),
'Number': ('Number', 'pydantic_schemaorg.Number', 'Number'),
'Blog': ('Blog', 'pydantic_schemaorg.Blog', 'Blog'),
'ShareAction': ('ShareAction', 'pydantic_schemaorg.ShareAction', 'ShareAction'),
'AerobicActivity': ('AerobicActivity', 'pydantic_schemaorg.AerobicActivity', 'AerobicActivity'),
'WorkersUnion': ('WorkersUnion', 'pydantic_schemaorg.WorkersUnion', 'WorkersUnion'),
'RealEstateAgent': ('RealEstateAgent', 'pydantic_schemaorg.RealEstateAgent', 'RealEstateAgent'),
'MenuSection': ('MenuSection', 'pydantic_schemaorg.MenuSection', 'MenuSection'),
'MusicRecording': ('MusicRecording', 'pydantic_schemaorg.MusicRecording', 'MusicRecording'),
'WearableSizeGroupBoys': ('WearableSizeGroupBoys', 'pydantic_schemaorg.WearableSizeGroupBoys', 'WearableSizeGroupBoys'),
'Event': ('Event', 'pydantic_schemaorg.Event', 'Event'),
'DanceEvent': ('DanceEvent', 'pydantic_schemaorg.DanceEvent', 'DanceEvent'),
'Project': ('Project', 'pydantic_schemaorg.Project', 'Project'),
'ResearchProject': ('ResearchProject', 'pydantic_schemaorg.ResearchProject', 'ResearchProject'),
'WearableSizeGroupInfants': ('WearableSizeGroupInfants', 'pydantic_schemaorg.WearableSizeGroupInfants', 'WearableSizeGroupInfants'),
'ScreeningEvent': ('ScreeningEvent', 'pydantic_schemaorg.ScreeningEvent', 'ScreeningEvent'),
'SocialMediaPosting': ('SocialMediaPosting', 'pydantic_schemaorg.SocialMediaPosting', 'SocialMediaPosting'),
'BlogPosting': ('BlogPosting', 'pydantic_schemaorg.BlogPosting', 'BlogPosting'),
'AnaerobicActivity': ('AnaerobicActivity', 'pydantic_schemaorg.AnaerobicActivity', 'AnaerobicActivity'),
'MedicalCause': ('MedicalCause', 'pydantic_schemaorg.MedicalCause', 'MedicalCause'),
'AutoRepair': ('AutoRepair', 'pydantic_schemaorg.AutoRepair', 'AutoRepair'),
'MobileApplication': ('MobileApplication', 'pydantic_schemaorg.MobileApplication', 'MobileApplication'),
'Campground': ('Campground', 'pydantic_schemaorg.Campground', 'Campground'),
'Nonprofit501c4': ('Nonprofit501c4', 'pydantic_schemaorg.Nonprofit501c4', 'Nonprofit501c4'),
'Online': ('Online', 'pydantic_schemaorg.Online', 'Online'),
'DryCleaningOrLaundry': ('DryCleaningOrLaundry', 'pydantic_schemaorg.DryCleaningOrLaundry', 'DryCleaningOrLaundry'),
'LiquorStore': ('LiquorStore', 'pydantic_schemaorg.LiquorStore', 'LiquorStore'),
'SizeSystemImperial': ('SizeSystemImperial', 'pydantic_schemaorg.SizeSystemImperial', 'SizeSystemImperial'),
'HealthPlanNetwork': ('HealthPlanNetwork', 'pydantic_schemaorg.HealthPlanNetwork', 'HealthPlanNetwork'),
'ScholarlyArticle': ('ScholarlyArticle', 'pydantic_schemaorg.ScholarlyArticle', 'ScholarlyArticle'),
'MedicalScholarlyArticle': ('MedicalScholarlyArticle', 'pydantic_schemaorg.MedicalScholarlyArticle', 'MedicalScholarlyArticle'),
'SelfStorage': ('SelfStorage', 'pydantic_schemaorg.SelfStorage', 'SelfStorage'),
'SoftwareSourceCode': ('SoftwareSourceCode', 'pydantic_schemaorg.SoftwareSourceCode', 'SoftwareSourceCode'),
'Researcher': ('Researcher', 'pydantic_schemaorg.Researcher', 'Researcher'),
'Nonprofit501c8': ('Nonprofit501c8', 'pydantic_schemaorg.Nonprofit501c8', 'Nonprofit501c8'),
'WearableSizeSystemBR': ('WearableSizeSystemBR', 'pydantic_schemaorg.WearableSizeSystemBR', 'WearableSizeSystemBR'),
'PriceTypeEnumeration': ('PriceTypeEnumeration', 'pydantic_schemaorg.PriceTypeEnumeration', 'PriceTypeEnumeration'),
'DefenceEstablishment': ('DefenceEstablishment', 'pydantic_schemaorg.DefenceEstablishment', 'DefenceEstablishment'),
'Nonprofit501q': ('Nonprofit501q', 'pydantic_schemaorg.Nonprofit501q', 'Nonprofit501q'),
'BodyMeasurementHips': ('BodyMeasurementHips', 'pydantic_schemaorg.BodyMeasurementHips', 'BodyMeasurementHips'),
'TireShop': ('TireShop', 'pydantic_schemaorg.TireShop', 'TireShop'),
'Hostel': ('Hostel', 'pydantic_schemaorg.Hostel', 'Hostel'),
'NutritionInformation': ('NutritionInformation', 'pydantic_schemaorg.NutritionInformation', 'NutritionInformation'),
'EducationalOccupationalProgram': ('EducationalOccupationalProgram', 'pydantic_schemaorg.EducationalOccupationalProgram', 'EducationalOccupationalProgram'),
'RadioClip': ('RadioClip', 'pydantic_schemaorg.RadioClip', 'RadioClip'),
'Nonprofit501c25': ('Nonprofit501c25', 'pydantic_schemaorg.Nonprofit501c25', 'Nonprofit501c25'),
'Nonprofit501c1': ('Nonprofit501c1', 'pydantic_schemaorg.Nonprofit501c1', 'Nonprofit501c1'),
'DataFeedItem': ('DataFeedItem', 'pydantic_schemaorg.DataFeedItem', 'DataFeedItem'),
'FastFoodRestaurant': ('FastFoodRestaurant', 'pydantic_schemaorg.FastFoodRestaurant', 'FastFoodRestaurant'),
'MedicalIndication': ('MedicalIndication', 'pydantic_schemaorg.MedicalIndication', 'MedicalIndication'),
'ApprovedIndication': ('ApprovedIndication', 'pydantic_schemaorg.ApprovedIndication', 'ApprovedIndication'),
'ExhibitionEvent': ('ExhibitionEvent', 'pydantic_schemaorg.ExhibitionEvent', 'ExhibitionEvent'),
'EUEnergyEfficiencyCategoryE': ('EUEnergyEfficiencyCategoryE', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryE', 'EUEnergyEfficiencyCategoryE'),
'DVDFormat': ('DVDFormat', 'pydantic_schemaorg.DVDFormat', 'DVDFormat'),
'ReadPermission': ('ReadPermission', 'pydantic_schemaorg.ReadPermission', 'ReadPermission'),
'WearableSizeSystemEN13402': ('WearableSizeSystemEN13402', 'pydantic_schemaorg.WearableSizeSystemEN13402', 'WearableSizeSystemEN13402'),
'PaymentDeclined': ('PaymentDeclined', 'pydantic_schemaorg.PaymentDeclined', 'PaymentDeclined'),
'Neck': ('Neck', 'pydantic_schemaorg.Neck', 'Neck'),
'Nonprofit501c28': ('Nonprofit501c28', 'pydantic_schemaorg.Nonprofit501c28', 'Nonprofit501c28'),
'Dermatologic': ('Dermatologic', 'pydantic_schemaorg.Dermatologic', 'Dermatologic'),
'WearableSizeGroupJuniors': ('WearableSizeGroupJuniors', 'pydantic_schemaorg.WearableSizeGroupJuniors', 'WearableSizeGroupJuniors'),
'Ultrasound': ('Ultrasound', 'pydantic_schemaorg.Ultrasound', 'Ultrasound'),
'SuspendAction': ('SuspendAction', 'pydantic_schemaorg.SuspendAction', 'SuspendAction'),
'Dentistry': ('Dentistry', 'pydantic_schemaorg.Dentistry', 'Dentistry'),
'TakeAction': ('TakeAction', 'pydantic_schemaorg.TakeAction', 'TakeAction'),
'ItemList': ('ItemList', 'pydantic_schemaorg.ItemList', 'ItemList'),
'BreadcrumbList': ('BreadcrumbList', 'pydantic_schemaorg.BreadcrumbList', 'BreadcrumbList'),
'MedicalTrialDesign': ('MedicalTrialDesign', 'pydantic_schemaorg.MedicalTrialDesign', 'MedicalTrialDesign'),
'TripleBlindedTrial': ('TripleBlindedTrial', 'pydantic_schemaorg.TripleBlindedTrial', 'TripleBlindedTrial'),
'AskPublicNewsArticle': ('AskPublicNewsArticle', 'pydantic_schemaorg.AskPublicNewsArticle', 'AskPublicNewsArticle'),
'UseAction': ('UseAction', 'pydantic_schemaorg.UseAction', 'UseAction'),
'AdministrativeArea': ('AdministrativeArea', 'pydantic_schemaorg.AdministrativeArea', 'AdministrativeArea'),
'SchoolDistrict': ('SchoolDistrict', 'pydantic_schemaorg.SchoolDistrict', 'SchoolDistrict'),
'WearableSizeGroupMaternity': ('WearableSizeGroupMaternity', 'pydantic_schemaorg.WearableSizeGroupMaternity', 'WearableSizeGroupMaternity'),
'PublicationIssue': ('PublicationIssue', 'pydantic_schemaorg.PublicationIssue', 'PublicationIssue'),
'ComicIssue': ('ComicIssue', 'pydantic_schemaorg.ComicIssue', 'ComicIssue'),
'Withdrawn': ('Withdrawn', 'pydantic_schemaorg.Withdrawn', 'Withdrawn'),
'ActionAccessSpecification': ('ActionAccessSpecification', 'pydantic_schemaorg.ActionAccessSpecification', 'ActionAccessSpecification'),
'Nonprofit501c16': ('Nonprofit501c16', 'pydantic_schemaorg.Nonprofit501c16', 'Nonprofit501c16'),
'QuantitativeValueDistribution': ('QuantitativeValueDistribution', 'pydantic_schemaorg.QuantitativeValueDistribution', 'QuantitativeValueDistribution'),
'Nonprofit501c11': ('Nonprofit501c11', 'pydantic_schemaorg.Nonprofit501c11', 'Nonprofit501c11'),
'ComputerStore': ('ComputerStore', 'pydantic_schemaorg.ComputerStore', 'ComputerStore'),
'MedicalWebPage': ('MedicalWebPage', 'pydantic_schemaorg.MedicalWebPage', 'MedicalWebPage'),
'HealthClub': ('HealthClub', 'pydantic_schemaorg.HealthClub', 'HealthClub'),
'OpenTrial': ('OpenTrial', 'pydantic_schemaorg.OpenTrial', 'OpenTrial'),
'ReservationStatusType': ('ReservationStatusType', 'pydantic_schemaorg.ReservationStatusType', 'ReservationStatusType'),
'ReservationCancelled': ('ReservationCancelled', 'pydantic_schemaorg.ReservationCancelled', 'ReservationCancelled'),
'Physiotherapy': ('Physiotherapy', 'pydantic_schemaorg.Physiotherapy', 'Physiotherapy'),
'RejectAction': ('RejectAction', 'pydantic_schemaorg.RejectAction', 'RejectAction'),
'TrainReservation': ('TrainReservation', 'pydantic_schemaorg.TrainReservation', 'TrainReservation'),
'Text': ('Text', 'pydantic_schemaorg.Text', 'Text'),
'XPathType': ('XPathType', 'pydantic_schemaorg.XPathType', 'XPathType'),
'MedicalRiskEstimator': ('MedicalRiskEstimator', 'pydantic_schemaorg.MedicalRiskEstimator', 'MedicalRiskEstimator'),
'EventAttendanceModeEnumeration': ('EventAttendanceModeEnumeration', 'pydantic_schemaorg.EventAttendanceModeEnumeration', 'EventAttendanceModeEnumeration'),
'BroadcastChannel': ('BroadcastChannel', 'pydantic_schemaorg.BroadcastChannel', 'BroadcastChannel'),
'RadioChannel': ('RadioChannel', 'pydantic_schemaorg.RadioChannel', 'RadioChannel'),
'AMRadioChannel': ('AMRadioChannel', 'pydantic_schemaorg.AMRadioChannel', 'AMRadioChannel'),
'Nonprofit501c12': ('Nonprofit501c12', 'pydantic_schemaorg.Nonprofit501c12', 'Nonprofit501c12'),
'Vessel': ('Vessel', 'pydantic_schemaorg.Vessel', 'Vessel'),
'Vein': ('Vein', 'pydantic_schemaorg.Vein', 'Vein'),
'PaidLeave': ('PaidLeave', 'pydantic_schemaorg.PaidLeave', 'PaidLeave'),
'LiveBlogPosting': ('LiveBlogPosting', 'pydantic_schemaorg.LiveBlogPosting', 'LiveBlogPosting'),
'SalePrice': ('SalePrice', 'pydantic_schemaorg.SalePrice', 'SalePrice'),
'ReactAction': ('ReactAction', 'pydantic_schemaorg.ReactAction', 'ReactAction'),
'LikeAction': ('LikeAction', 'pydantic_schemaorg.LikeAction', 'LikeAction'),
'LegalService': ('LegalService', 'pydantic_schemaorg.LegalService', 'LegalService'),
'MusicEvent': ('MusicEvent', 'pydantic_schemaorg.MusicEvent', 'MusicEvent'),
'Resort': ('Resort', 'pydantic_schemaorg.Resort', 'Resort'),
'SkiResort': ('SkiResort', 'pydantic_schemaorg.SkiResort', 'SkiResort'),
'DrinkAction': ('DrinkAction', 'pydantic_schemaorg.DrinkAction', 'DrinkAction'),
'Nursing': ('Nursing', 'pydantic_schemaorg.Nursing', 'Nursing'),
'PaymentMethod': ('PaymentMethod', 'pydantic_schemaorg.PaymentMethod', 'PaymentMethod'),
'PaymentCard': ('PaymentCard', 'pydantic_schemaorg.PaymentCard', 'PaymentCard'),
'ProfilePage': ('ProfilePage', 'pydantic_schemaorg.ProfilePage', 'ProfilePage'),
'MusicRelease': ('MusicRelease', 'pydantic_schemaorg.MusicRelease', 'MusicRelease'),
'Painting': ('Painting', 'pydantic_schemaorg.Painting', 'Painting'),
'EUEnergyEfficiencyCategoryA2Plus': ('EUEnergyEfficiencyCategoryA2Plus', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryA2Plus', 'EUEnergyEfficiencyCategoryA2Plus'),
'MixedEventAttendanceMode': ('MixedEventAttendanceMode', 'pydantic_schemaorg.MixedEventAttendanceMode', 'MixedEventAttendanceMode'),
'BackOrder': ('BackOrder', 'pydantic_schemaorg.BackOrder', 'BackOrder'),
'ArriveAction': ('ArriveAction', 'pydantic_schemaorg.ArriveAction', 'ArriveAction'),
'CleaningFee': ('CleaningFee', 'pydantic_schemaorg.CleaningFee', 'CleaningFee'),
'Pharmacy': ('Pharmacy', 'pydantic_schemaorg.Pharmacy', 'Pharmacy'),
'NightClub': ('NightClub', 'pydantic_schemaorg.NightClub', 'NightClub'),
'Nonprofit501k': ('Nonprofit501k', 'pydantic_schemaorg.Nonprofit501k', 'Nonprofit501k'),
'Nonprofit501c17': ('Nonprofit501c17', 'pydantic_schemaorg.Nonprofit501c17', 'Nonprofit501c17'),
'OwnershipInfo': ('OwnershipInfo', 'pydantic_schemaorg.OwnershipInfo', 'OwnershipInfo'),
'Grant': ('Grant', 'pydantic_schemaorg.Grant', 'Grant'),
'MonetaryGrant': ('MonetaryGrant', 'pydantic_schemaorg.MonetaryGrant', 'MonetaryGrant'),
'Periodical': ('Periodical', 'pydantic_schemaorg.Periodical', 'Periodical'),
'ComicSeries': ('ComicSeries', 'pydantic_schemaorg.ComicSeries', 'ComicSeries'),
'ImageObject': ('ImageObject', 'pydantic_schemaorg.ImageObject', 'ImageObject'),
'PaymentDue': ('PaymentDue', 'pydantic_schemaorg.PaymentDue', 'PaymentDue'),
'TaxiVehicleUsage': ('TaxiVehicleUsage', 'pydantic_schemaorg.TaxiVehicleUsage', 'TaxiVehicleUsage'),
'CardiovascularExam': ('CardiovascularExam', 'pydantic_schemaorg.CardiovascularExam', 'CardiovascularExam'),
'QualitativeValue': ('QualitativeValue', 'pydantic_schemaorg.QualitativeValue', 'QualitativeValue'),
'SteeringPositionValue': ('SteeringPositionValue', 'pydantic_schemaorg.SteeringPositionValue', 'SteeringPositionValue'),
'LeftHandDriving': ('LeftHandDriving', 'pydantic_schemaorg.LeftHandDriving', 'LeftHandDriving'),
'OrderStatus': ('OrderStatus', 'pydantic_schemaorg.OrderStatus', 'OrderStatus'),
'OrderInTransit': ('OrderInTransit', 'pydantic_schemaorg.OrderInTransit', 'OrderInTransit'),
'MedicalTestPanel': ('MedicalTestPanel', 'pydantic_schemaorg.MedicalTestPanel', 'MedicalTestPanel'),
'WearableSizeSystemUS': ('WearableSizeSystemUS', 'pydantic_schemaorg.WearableSizeSystemUS', 'WearableSizeSystemUS'),
'DefinedTermSet': ('DefinedTermSet', 'pydantic_schemaorg.DefinedTermSet', 'DefinedTermSet'),
'HyperTocEntry': ('HyperTocEntry', 'pydantic_schemaorg.HyperTocEntry', 'HyperTocEntry'),
'WatchAction': ('WatchAction', 'pydantic_schemaorg.WatchAction', 'WatchAction'),
'Report': ('Report', 'pydantic_schemaorg.Report', 'Report'),
'Notary': ('Notary', 'pydantic_schemaorg.Notary', 'Notary'),
'Distillery': ('Distillery', 'pydantic_schemaorg.Distillery', 'Distillery'),
'QuantitativeValue': ('QuantitativeValue', 'pydantic_schemaorg.QuantitativeValue', 'QuantitativeValue'),
'DepartmentStore': ('DepartmentStore', 'pydantic_schemaorg.DepartmentStore', 'DepartmentStore'),
'TVSeries': ('TVSeries', 'pydantic_schemaorg.TVSeries', 'TVSeries'),
'ScreeningHealthAspect': ('ScreeningHealthAspect', 'pydantic_schemaorg.ScreeningHealthAspect', 'ScreeningHealthAspect'),
'OutOfStock': ('OutOfStock', 'pydantic_schemaorg.OutOfStock', 'OutOfStock'),
'QAPage': ('QAPage', 'pydantic_schemaorg.QAPage', 'QAPage'),
'RentalCarReservation': ('RentalCarReservation', 'pydantic_schemaorg.RentalCarReservation', 'RentalCarReservation'),
'LockerDelivery': ('LockerDelivery', 'pydantic_schemaorg.LockerDelivery', 'LockerDelivery'),
'EmployerReview': ('EmployerReview', 'pydantic_schemaorg.EmployerReview', 'EmployerReview'),
'DataCatalog': ('DataCatalog', 'pydantic_schemaorg.DataCatalog', 'DataCatalog'),
'ParentalSupport': ('ParentalSupport', 'pydantic_schemaorg.ParentalSupport', 'ParentalSupport'),
'RefundTypeEnumeration': ('RefundTypeEnumeration', 'pydantic_schemaorg.RefundTypeEnumeration', 'RefundTypeEnumeration'),
'MerchantReturnEnumeration': ('MerchantReturnEnumeration', 'pydantic_schemaorg.MerchantReturnEnumeration', 'MerchantReturnEnumeration'),
'MerchantReturnNotPermitted': ('MerchantReturnNotPermitted', 'pydantic_schemaorg.MerchantReturnNotPermitted', 'MerchantReturnNotPermitted'),
'EUEnergyEfficiencyCategoryB': ('EUEnergyEfficiencyCategoryB', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryB', 'EUEnergyEfficiencyCategoryB'),
'ClothingStore': ('ClothingStore', 'pydantic_schemaorg.ClothingStore', 'ClothingStore'),
'AutoRental': ('AutoRental', 'pydantic_schemaorg.AutoRental', 'AutoRental'),
'RoofingContractor': ('RoofingContractor', 'pydantic_schemaorg.RoofingContractor', 'RoofingContractor'),
'LimitedAvailability': ('LimitedAvailability', 'pydantic_schemaorg.LimitedAvailability', 'LimitedAvailability'),
'Nonprofit501c20': ('Nonprofit501c20', 'pydantic_schemaorg.Nonprofit501c20', 'Nonprofit501c20'),
'SportsOrganization': ('SportsOrganization', 'pydantic_schemaorg.SportsOrganization', 'SportsOrganization'),
'TaxiService': ('TaxiService', 'pydantic_schemaorg.TaxiService', 'TaxiService'),
'Wholesale': ('Wholesale', 'pydantic_schemaorg.Wholesale', 'Wholesale'),
'ListItem': ('ListItem', 'pydantic_schemaorg.ListItem', 'ListItem'),
'HowToSection': ('HowToSection', 'pydantic_schemaorg.HowToSection', 'HowToSection'),
'Endocrine': ('Endocrine', 'pydantic_schemaorg.Endocrine', 'Endocrine'),
'Terminated': ('Terminated', 'pydantic_schemaorg.Terminated', 'Terminated'),
'EducationalOrganization': ('EducationalOrganization', 'pydantic_schemaorg.EducationalOrganization', 'EducationalOrganization'),
'School': ('School', 'pydantic_schemaorg.School', 'School'),
'MusicStore': ('MusicStore', 'pydantic_schemaorg.MusicStore', 'MusicStore'),
'WearableMeasurementCollar': ('WearableMeasurementCollar', 'pydantic_schemaorg.WearableMeasurementCollar', 'WearableMeasurementCollar'),
'ExerciseGym': ('ExerciseGym', 'pydantic_schemaorg.ExerciseGym', 'ExerciseGym'),
'EngineSpecification': ('EngineSpecification', 'pydantic_schemaorg.EngineSpecification', 'EngineSpecification'),
'MixtapeAlbum': ('MixtapeAlbum', 'pydantic_schemaorg.MixtapeAlbum', 'MixtapeAlbum'),
'SafetyHealthAspect': ('SafetyHealthAspect', 'pydantic_schemaorg.SafetyHealthAspect', 'SafetyHealthAspect'),
'InfectiousDisease': ('InfectiousDisease', 'pydantic_schemaorg.InfectiousDisease', 'InfectiousDisease'),
'EvidenceLevelB': ('EvidenceLevelB', 'pydantic_schemaorg.EvidenceLevelB', 'EvidenceLevelB'),
'LaserDiscFormat': ('LaserDiscFormat', 'pydantic_schemaorg.LaserDiscFormat', 'LaserDiscFormat'),
'DateTime': ('DateTime', 'pydantic_schemaorg.DateTime', 'DateTime'),
'Rating': ('Rating', 'pydantic_schemaorg.Rating', 'Rating'),
'PublicationEvent': ('PublicationEvent', 'pydantic_schemaorg.PublicationEvent', 'PublicationEvent'),
'InfectiousAgentClass': ('InfectiousAgentClass', 'pydantic_schemaorg.InfectiousAgentClass', 'InfectiousAgentClass'),
'Protozoa': ('Protozoa', 'pydantic_schemaorg.Protozoa', 'Protozoa'),
'BodyMeasurementChest': ('BodyMeasurementChest', 'pydantic_schemaorg.BodyMeasurementChest', 'BodyMeasurementChest'),
'Brand': ('Brand', 'pydantic_schemaorg.Brand', 'Brand'),
'BusReservation': ('BusReservation', 'pydantic_schemaorg.BusReservation', 'BusReservation'),
'EPRelease': ('EPRelease', 'pydantic_schemaorg.EPRelease', 'EPRelease'),
'CurrencyConversionService': ('CurrencyConversionService', 'pydantic_schemaorg.CurrencyConversionService', 'CurrencyConversionService'),
'DisagreeAction': ('DisagreeAction', 'pydantic_schemaorg.DisagreeAction', 'DisagreeAction'),
'ReservationHold': ('ReservationHold', 'pydantic_schemaorg.ReservationHold', 'ReservationHold'),
'PreSale': ('PreSale', 'pydantic_schemaorg.PreSale', 'PreSale'),
'OrderProcessing': ('OrderProcessing', 'pydantic_schemaorg.OrderProcessing', 'OrderProcessing'),
'Country': ('Country', 'pydantic_schemaorg.Country', 'Country'),
'DeliveryTimeSettings': ('DeliveryTimeSettings', 'pydantic_schemaorg.DeliveryTimeSettings', 'DeliveryTimeSettings'),
'WorkBasedProgram': ('WorkBasedProgram', 'pydantic_schemaorg.WorkBasedProgram', 'WorkBasedProgram'),
'EUEnergyEfficiencyCategoryA1Plus': ('EUEnergyEfficiencyCategoryA1Plus', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryA1Plus', 'EUEnergyEfficiencyCategoryA1Plus'),
'Nonprofit501c13': ('Nonprofit501c13', 'pydantic_schemaorg.Nonprofit501c13', 'Nonprofit501c13'),
'VenueMap': ('VenueMap', 'pydantic_schemaorg.VenueMap', 'VenueMap'),
'PlayAction': ('PlayAction', 'pydantic_schemaorg.PlayAction', 'PlayAction'),
'ExerciseAction': ('ExerciseAction', 'pydantic_schemaorg.ExerciseAction', 'ExerciseAction'),
'PhysicalTherapy': ('PhysicalTherapy', 'pydantic_schemaorg.PhysicalTherapy', 'PhysicalTherapy'),
'EventRescheduled': ('EventRescheduled', 'pydantic_schemaorg.EventRescheduled', 'EventRescheduled'),
'UpdateAction': ('UpdateAction', 'pydantic_schemaorg.UpdateAction', 'UpdateAction'),
'AddAction': ('AddAction', 'pydantic_schemaorg.AddAction', 'AddAction'),
'InsertAction': ('InsertAction', 'pydantic_schemaorg.InsertAction', 'InsertAction'),
'PrependAction': ('PrependAction', 'pydantic_schemaorg.PrependAction', 'PrependAction'),
'MultiCenterTrial': ('MultiCenterTrial', 'pydantic_schemaorg.MultiCenterTrial', 'MultiCenterTrial'),
'Brewery': ('Brewery', 'pydantic_schemaorg.Brewery', 'Brewery'),
'CreateAction': ('CreateAction', 'pydantic_schemaorg.CreateAction', 'CreateAction'),
'House': ('House', 'pydantic_schemaorg.House', 'House'),
'SingleFamilyResidence': ('SingleFamilyResidence', 'pydantic_schemaorg.SingleFamilyResidence', 'SingleFamilyResidence'),
'Vehicle': ('Vehicle', 'pydantic_schemaorg.Vehicle', 'Vehicle'),
'DemoAlbum': ('DemoAlbum', 'pydantic_schemaorg.DemoAlbum', 'DemoAlbum'),
'PublicHealth': ('PublicHealth', 'pydantic_schemaorg.PublicHealth', 'PublicHealth'),
'ContagiousnessHealthAspect': ('ContagiousnessHealthAspect', 'pydantic_schemaorg.ContagiousnessHealthAspect', 'ContagiousnessHealthAspect'),
'FlightReservation': ('FlightReservation', 'pydantic_schemaorg.FlightReservation', 'FlightReservation'),
'AppendAction': ('AppendAction', 'pydantic_schemaorg.AppendAction', 'AppendAction'),
'Nonprofit501c9': ('Nonprofit501c9', 'pydantic_schemaorg.Nonprofit501c9', 'Nonprofit501c9'),
'StadiumOrArena': ('StadiumOrArena', 'pydantic_schemaorg.StadiumOrArena', 'StadiumOrArena'),
'Physician': ('Physician', 'pydantic_schemaorg.Physician', 'Physician'),
'MonetaryAmountDistribution': ('MonetaryAmountDistribution', 'pydantic_schemaorg.MonetaryAmountDistribution', 'MonetaryAmountDistribution'),
'TheaterEvent': ('TheaterEvent', 'pydantic_schemaorg.TheaterEvent', 'TheaterEvent'),
'MeetingRoom': ('MeetingRoom', 'pydantic_schemaorg.MeetingRoom', 'MeetingRoom'),
'ArchiveComponent': ('ArchiveComponent', 'pydantic_schemaorg.ArchiveComponent', 'ArchiveComponent'),
'BarOrPub': ('BarOrPub', 'pydantic_schemaorg.BarOrPub', 'BarOrPub'),
'EnergyConsumptionDetails': ('EnergyConsumptionDetails', 'pydantic_schemaorg.EnergyConsumptionDetails', 'EnergyConsumptionDetails'),
'EducationalOccupationalCredential': ('EducationalOccupationalCredential', 'pydantic_schemaorg.EducationalOccupationalCredential', 'EducationalOccupationalCredential'),
'MulticellularParasite': ('MulticellularParasite', 'pydantic_schemaorg.MulticellularParasite', 'MulticellularParasite'),
'Offer': ('Offer', 'pydantic_schemaorg.Offer', 'Offer'),
'OfferForLease': ('OfferForLease', 'pydantic_schemaorg.OfferForLease', 'OfferForLease'),
'ExchangeRefund': ('ExchangeRefund', 'pydantic_schemaorg.ExchangeRefund', 'ExchangeRefund'),
'TipAction': ('TipAction', 'pydantic_schemaorg.TipAction', 'TipAction'),
'AskAction': ('AskAction', 'pydantic_schemaorg.AskAction', 'AskAction'),
'HVACBusiness': ('HVACBusiness', 'pydantic_schemaorg.HVACBusiness', 'HVACBusiness'),
'RadioSeries': ('RadioSeries', 'pydantic_schemaorg.RadioSeries', 'RadioSeries'),
'TreatmentIndication': ('TreatmentIndication', 'pydantic_schemaorg.TreatmentIndication', 'TreatmentIndication'),
'WesternConventional': ('WesternConventional', 'pydantic_schemaorg.WesternConventional', 'WesternConventional'),
'Trip': ('Trip', 'pydantic_schemaorg.Trip', 'Trip'),
'TrainTrip': ('TrainTrip', 'pydantic_schemaorg.TrainTrip', 'TrainTrip'),
'JobPosting': ('JobPosting', 'pydantic_schemaorg.JobPosting', 'JobPosting'),
'BusStation': ('BusStation', 'pydantic_schemaorg.BusStation', 'BusStation'),
'WearableSizeSystemUK': ('WearableSizeSystemUK', 'pydantic_schemaorg.WearableSizeSystemUK', 'WearableSizeSystemUK'),
'WearableMeasurementOutsideLeg': ('WearableMeasurementOutsideLeg', 'pydantic_schemaorg.WearableMeasurementOutsideLeg', 'WearableMeasurementOutsideLeg'),
'Collection': ('Collection', 'pydantic_schemaorg.Collection', 'Collection'),
'Skin': ('Skin', 'pydantic_schemaorg.Skin', 'Skin'),
'FDAcategoryD': ('FDAcategoryD', 'pydantic_schemaorg.FDAcategoryD', 'FDAcategoryD'),
'MiddleSchool': ('MiddleSchool', 'pydantic_schemaorg.MiddleSchool', 'MiddleSchool'),
'BookFormatType': ('BookFormatType', 'pydantic_schemaorg.BookFormatType', 'BookFormatType'),
'GraphicNovel': ('GraphicNovel', 'pydantic_schemaorg.GraphicNovel', 'GraphicNovel'),
'PostalCodeRangeSpecification': ('PostalCodeRangeSpecification', 'pydantic_schemaorg.PostalCodeRangeSpecification', 'PostalCodeRangeSpecification'),
'Emergency': ('Emergency', 'pydantic_schemaorg.Emergency', 'Emergency'),
'SingleRelease': ('SingleRelease', 'pydantic_schemaorg.SingleRelease', 'SingleRelease'),
'Nonprofit501c15': ('Nonprofit501c15', 'pydantic_schemaorg.Nonprofit501c15', 'Nonprofit501c15'),
'AggregateRating': ('AggregateRating', 'pydantic_schemaorg.AggregateRating', 'AggregateRating'),
'EmployerAggregateRating': ('EmployerAggregateRating', 'pydantic_schemaorg.EmployerAggregateRating', 'EmployerAggregateRating'),
'AutoBodyShop': ('AutoBodyShop', 'pydantic_schemaorg.AutoBodyShop', 'AutoBodyShop'),
'EmploymentAgency': ('EmploymentAgency', 'pydantic_schemaorg.EmploymentAgency', 'EmploymentAgency'),
'Ticket': ('Ticket', 'pydantic_schemaorg.Ticket', 'Ticket'),
'WearableSizeGroupRegular': ('WearableSizeGroupRegular', 'pydantic_schemaorg.WearableSizeGroupRegular', 'WearableSizeGroupRegular'),
'SatireOrParodyContent': ('SatireOrParodyContent', 'pydantic_schemaorg.SatireOrParodyContent', 'SatireOrParodyContent'),
'BroadcastFrequencySpecification': ('BroadcastFrequencySpecification', 'pydantic_schemaorg.BroadcastFrequencySpecification', 'BroadcastFrequencySpecification'),
'RadioStation': ('RadioStation', 'pydantic_schemaorg.RadioStation', 'RadioStation'),
'GenderType': ('GenderType', 'pydantic_schemaorg.GenderType', 'GenderType'),
'VeterinaryCare': ('VeterinaryCare', 'pydantic_schemaorg.VeterinaryCare', 'VeterinaryCare'),
'UnofficialLegalValue': ('UnofficialLegalValue', 'pydantic_schemaorg.UnofficialLegalValue', 'UnofficialLegalValue'),
'Nonprofit501c10': ('Nonprofit501c10', 'pydantic_schemaorg.Nonprofit501c10', 'Nonprofit501c10'),
'GlutenFreeDiet': ('GlutenFreeDiet', 'pydantic_schemaorg.GlutenFreeDiet', 'GlutenFreeDiet'),
'URL': ('URL', 'pydantic_schemaorg.URL', 'URL'),
'AchieveAction': ('AchieveAction', 'pydantic_schemaorg.AchieveAction', 'AchieveAction'),
'WinAction': ('WinAction', 'pydantic_schemaorg.WinAction', 'WinAction'),
'SatiricalArticle': ('SatiricalArticle', 'pydantic_schemaorg.SatiricalArticle', 'SatiricalArticle'),
'Book': ('Book', 'pydantic_schemaorg.Book', 'Book'),
'BloodTest': ('BloodTest', 'pydantic_schemaorg.BloodTest', 'BloodTest'),
'WearableMeasurementCup': ('WearableMeasurementCup', 'pydantic_schemaorg.WearableMeasurementCup', 'WearableMeasurementCup'),
'WearableSizeSystemCN': ('WearableSizeSystemCN', 'pydantic_schemaorg.WearableSizeSystemCN', 'WearableSizeSystemCN'),
'DisabilitySupport': ('DisabilitySupport', 'pydantic_schemaorg.DisabilitySupport', 'DisabilitySupport'),
'Occupation': ('Occupation', 'pydantic_schemaorg.Occupation', 'Occupation'),
'Plumber': ('Plumber', 'pydantic_schemaorg.Plumber', 'Plumber'),
'AuthoritativeLegalValue': ('AuthoritativeLegalValue', 'pydantic_schemaorg.AuthoritativeLegalValue', 'AuthoritativeLegalValue'),
'CausesHealthAspect': ('CausesHealthAspect', 'pydantic_schemaorg.CausesHealthAspect', 'CausesHealthAspect'),
'Optician': ('Optician', 'pydantic_schemaorg.Optician', 'Optician'),
'Geriatric': ('Geriatric', 'pydantic_schemaorg.Geriatric', 'Geriatric'),
'GovernmentOffice': ('GovernmentOffice', 'pydantic_schemaorg.GovernmentOffice', 'GovernmentOffice'),
'SingleCenterTrial': ('SingleCenterTrial', 'pydantic_schemaorg.SingleCenterTrial', 'SingleCenterTrial'),
'Preschool': ('Preschool', 'pydantic_schemaorg.Preschool', 'Preschool'),
'DownloadAction': ('DownloadAction', 'pydantic_schemaorg.DownloadAction', 'DownloadAction'),
'HairSalon': ('HairSalon', 'pydantic_schemaorg.HairSalon', 'HairSalon'),
'AcceptAction': ('AcceptAction', 'pydantic_schemaorg.AcceptAction', 'AcceptAction'),
'Abdomen': ('Abdomen', 'pydantic_schemaorg.Abdomen', 'Abdomen'),
'CoOp': ('CoOp', 'pydantic_schemaorg.CoOp', 'CoOp'),
'UserInteraction': ('UserInteraction', 'pydantic_schemaorg.UserInteraction', 'UserInteraction'),
'UserPlays': ('UserPlays', 'pydantic_schemaorg.UserPlays', 'UserPlays'),
'OverviewHealthAspect': ('OverviewHealthAspect', 'pydantic_schemaorg.OverviewHealthAspect', 'OverviewHealthAspect'),
'MotorcycleDealer': ('MotorcycleDealer', 'pydantic_schemaorg.MotorcycleDealer', 'MotorcycleDealer'),
'SymptomsHealthAspect': ('SymptomsHealthAspect', 'pydantic_schemaorg.SymptomsHealthAspect', 'SymptomsHealthAspect'),
'Drug': ('Drug', 'pydantic_schemaorg.Drug', 'Drug'),
'PaymentComplete': ('PaymentComplete', 'pydantic_schemaorg.PaymentComplete', 'PaymentComplete'),
'MedicalObservationalStudyDesign': ('MedicalObservationalStudyDesign', 'pydantic_schemaorg.MedicalObservationalStudyDesign', 'MedicalObservationalStudyDesign'),
'CohortStudy': ('CohortStudy', 'pydantic_schemaorg.CohortStudy', 'CohortStudy'),
'SurgicalProcedure': ('SurgicalProcedure', 'pydantic_schemaorg.SurgicalProcedure', 'SurgicalProcedure'),
'PerformingGroup': ('PerformingGroup', 'pydantic_schemaorg.PerformingGroup', 'PerformingGroup'),
'TheaterGroup': ('TheaterGroup', 'pydantic_schemaorg.TheaterGroup', 'TheaterGroup'),
'EnrollingByInvitation': ('EnrollingByInvitation', 'pydantic_schemaorg.EnrollingByInvitation', 'EnrollingByInvitation'),
'PaymentService': ('PaymentService', 'pydantic_schemaorg.PaymentService', 'PaymentService'),
'WearableMeasurementLength': ('WearableMeasurementLength', 'pydantic_schemaorg.WearableMeasurementLength', 'WearableMeasurementLength'),
'PrimaryCare': ('PrimaryCare', 'pydantic_schemaorg.PrimaryCare', 'PrimaryCare'),
'WebApplication': ('WebApplication', 'pydantic_schemaorg.WebApplication', 'WebApplication'),
'CityHall': ('CityHall', 'pydantic_schemaorg.CityHall', 'CityHall'),
'ShoeStore': ('ShoeStore', 'pydantic_schemaorg.ShoeStore', 'ShoeStore'),
'InteractionCounter': ('InteractionCounter', 'pydantic_schemaorg.InteractionCounter', 'InteractionCounter'),
'ChildrensEvent': ('ChildrensEvent', 'pydantic_schemaorg.ChildrensEvent', 'ChildrensEvent'),
'ReviewAction': ('ReviewAction', 'pydantic_schemaorg.ReviewAction', 'ReviewAction'),
'ReturnLabelInBox': ('ReturnLabelInBox', 'pydantic_schemaorg.ReturnLabelInBox', 'ReturnLabelInBox'),
'DriveWheelConfigurationValue': ('DriveWheelConfigurationValue', 'pydantic_schemaorg.DriveWheelConfigurationValue', 'DriveWheelConfigurationValue'),
'FrontWheelDriveConfiguration': ('FrontWheelDriveConfiguration', 'pydantic_schemaorg.FrontWheelDriveConfiguration', 'FrontWheelDriveConfiguration'),
'Nonprofit501c3': ('Nonprofit501c3', 'pydantic_schemaorg.Nonprofit501c3', 'Nonprofit501c3'),
'BrainStructure': ('BrainStructure', 'pydantic_schemaorg.BrainStructure', 'BrainStructure'),
'MusicVenue': ('MusicVenue', 'pydantic_schemaorg.MusicVenue', 'MusicVenue'),
'SellAction': ('SellAction', 'pydantic_schemaorg.SellAction', 'SellAction'),
'DigitalFormat': ('DigitalFormat', 'pydantic_schemaorg.DigitalFormat', 'DigitalFormat'),
'VisualArtsEvent': ('VisualArtsEvent', 'pydantic_schemaorg.VisualArtsEvent', 'VisualArtsEvent'),
'AudioObject': ('AudioObject', 'pydantic_schemaorg.AudioObject', 'AudioObject'),
'Audiobook': ('Audiobook', 'pydantic_schemaorg.Audiobook', 'Audiobook'),
'CheckOutAction': ('CheckOutAction', 'pydantic_schemaorg.CheckOutAction', 'CheckOutAction'),
'UnitPriceSpecification': ('UnitPriceSpecification', 'pydantic_schemaorg.UnitPriceSpecification', 'UnitPriceSpecification'),
'BoatTrip': ('BoatTrip', 'pydantic_schemaorg.BoatTrip', 'BoatTrip'),
'EmergencyService': ('EmergencyService', 'pydantic_schemaorg.EmergencyService', 'EmergencyService'),
'FireStation': ('FireStation', 'pydantic_schemaorg.FireStation', 'FireStation'),
'ContactPointOption': ('ContactPointOption', 'pydantic_schemaorg.ContactPointOption', 'ContactPointOption'),
'HearingImpairedSupported': ('HearingImpairedSupported', 'pydantic_schemaorg.HearingImpairedSupported', 'HearingImpairedSupported'),
'OfferShippingDetails': ('OfferShippingDetails', 'pydantic_schemaorg.OfferShippingDetails', 'OfferShippingDetails'),
'MenuItem': ('MenuItem', 'pydantic_schemaorg.MenuItem', 'MenuItem'),
'Crematorium': ('Crematorium', 'pydantic_schemaorg.Crematorium', 'Crematorium'),
'Protein': ('Protein', 'pydantic_schemaorg.Protein', 'Protein'),
'WearableMeasurementChestOrBust': ('WearableMeasurementChestOrBust', 'pydantic_schemaorg.WearableMeasurementChestOrBust', 'WearableMeasurementChestOrBust'),
'WantAction': ('WantAction', 'pydantic_schemaorg.WantAction', 'WantAction'),
'HyperToc': ('HyperToc', 'pydantic_schemaorg.HyperToc', 'HyperToc'),
'TrackAction': ('TrackAction', 'pydantic_schemaorg.TrackAction', 'TrackAction'),
'CommunityHealth': ('CommunityHealth', 'pydantic_schemaorg.CommunityHealth', 'CommunityHealth'),
'OfficialLegalValue': ('OfficialLegalValue', 'pydantic_schemaorg.OfficialLegalValue', 'OfficialLegalValue'),
'Installment': ('Installment', 'pydantic_schemaorg.Installment', 'Installment'),
'WearableSizeGroupHusky': ('WearableSizeGroupHusky', 'pydantic_schemaorg.WearableSizeGroupHusky', 'WearableSizeGroupHusky'),
'Duration': ('Duration', 'pydantic_schemaorg.Duration', 'Duration'),
'NLNonprofitType': ('NLNonprofitType', 'pydantic_schemaorg.NLNonprofitType', 'NLNonprofitType'),
'NonprofitSBBI': ('NonprofitSBBI', 'pydantic_schemaorg.NonprofitSBBI', 'NonprofitSBBI'),
'BackgroundNewsArticle': ('BackgroundNewsArticle', 'pydantic_schemaorg.BackgroundNewsArticle', 'BackgroundNewsArticle'),
'Course': ('Course', 'pydantic_schemaorg.Course', 'Course'),
'RespiratoryTherapy': ('RespiratoryTherapy', 'pydantic_schemaorg.RespiratoryTherapy', 'RespiratoryTherapy'),
'Bakery': ('Bakery', 'pydantic_schemaorg.Bakery', 'Bakery'),
'HowTo': ('HowTo', 'pydantic_schemaorg.HowTo', 'HowTo'),
'Hackathon': ('Hackathon', 'pydantic_schemaorg.Hackathon', 'Hackathon'),
'ReturnAtKiosk': ('ReturnAtKiosk', 'pydantic_schemaorg.ReturnAtKiosk', 'ReturnAtKiosk'),
'HowToDirection': ('HowToDirection', 'pydantic_schemaorg.HowToDirection', 'HowToDirection'),
'ContactPoint': ('ContactPoint', 'pydantic_schemaorg.ContactPoint', 'ContactPoint'),
'PostalAddress': ('PostalAddress', 'pydantic_schemaorg.PostalAddress', 'PostalAddress'),
'Surgical': ('Surgical', 'pydantic_schemaorg.Surgical', 'Surgical'),
'Male': ('Male', 'pydantic_schemaorg.Male', 'Male'),
'UserBlocks': ('UserBlocks', 'pydantic_schemaorg.UserBlocks', 'UserBlocks'),
'AuthorizeAction': ('AuthorizeAction', 'pydantic_schemaorg.AuthorizeAction', 'AuthorizeAction'),
'UsedCondition': ('UsedCondition', 'pydantic_schemaorg.UsedCondition', 'UsedCondition'),
'UserPlusOnes': ('UserPlusOnes', 'pydantic_schemaorg.UserPlusOnes', 'UserPlusOnes'),
'RandomizedTrial': ('RandomizedTrial', 'pydantic_schemaorg.RandomizedTrial', 'RandomizedTrial'),
'WPHeader': ('WPHeader', 'pydantic_schemaorg.WPHeader', 'WPHeader'),
'Quotation': ('Quotation', 'pydantic_schemaorg.Quotation', 'Quotation'),
'TraditionalChinese': ('TraditionalChinese', 'pydantic_schemaorg.TraditionalChinese', 'TraditionalChinese'),
'MusicVideoObject': ('MusicVideoObject', 'pydantic_schemaorg.MusicVideoObject', 'MusicVideoObject'),
'PlasticSurgery': ('PlasticSurgery', 'pydantic_schemaorg.PlasticSurgery', 'PlasticSurgery'),
'EventSeries': ('EventSeries', 'pydantic_schemaorg.EventSeries', 'EventSeries'),
'Thursday': ('Thursday', 'pydantic_schemaorg.Thursday', 'Thursday'),
'MedicalRiskFactor': ('MedicalRiskFactor', 'pydantic_schemaorg.MedicalRiskFactor', 'MedicalRiskFactor'),
'Flight': ('Flight', 'pydantic_schemaorg.Flight', 'Flight'),
'Movie': ('Movie', 'pydantic_schemaorg.Movie', 'Movie'),
'Newspaper': ('Newspaper', 'pydantic_schemaorg.Newspaper', 'Newspaper'),
'Obstetric': ('Obstetric', 'pydantic_schemaorg.Obstetric', 'Obstetric'),
'FoodEvent': ('FoodEvent', 'pydantic_schemaorg.FoodEvent', 'FoodEvent'),
'MovieRentalStore': ('MovieRentalStore', 'pydantic_schemaorg.MovieRentalStore', 'MovieRentalStore'),
'BankAccount': ('BankAccount', 'pydantic_schemaorg.BankAccount', 'BankAccount'),
'WearableSizeGroupExtraTall': ('WearableSizeGroupExtraTall', 'pydantic_schemaorg.WearableSizeGroupExtraTall', 'WearableSizeGroupExtraTall'),
'BodyMeasurementHeight': ('BodyMeasurementHeight', 'pydantic_schemaorg.BodyMeasurementHeight', 'BodyMeasurementHeight'),
'LeaveAction': ('LeaveAction', 'pydantic_schemaorg.LeaveAction', 'LeaveAction'),
'MusicComposition': ('MusicComposition', 'pydantic_schemaorg.MusicComposition', 'MusicComposition'),
'ActionStatusType': ('ActionStatusType', 'pydantic_schemaorg.ActionStatusType', 'ActionStatusType'),
'CompletedActionStatus': ('CompletedActionStatus', 'pydantic_schemaorg.CompletedActionStatus', 'CompletedActionStatus'),
'DiagnosticLab': ('DiagnosticLab', 'pydantic_schemaorg.DiagnosticLab', 'DiagnosticLab'),
'FAQPage': ('FAQPage', 'pydantic_schemaorg.FAQPage', 'FAQPage'),
'SaleEvent': ('SaleEvent', 'pydantic_schemaorg.SaleEvent', 'SaleEvent'),
'Joint': ('Joint', 'pydantic_schemaorg.Joint', 'Joint'),
'GardenStore': ('GardenStore', 'pydantic_schemaorg.GardenStore', 'GardenStore'),
'PronounceableText': ('PronounceableText', 'pydantic_schemaorg.PronounceableText', 'PronounceableText'),
'PetStore': ('PetStore', 'pydantic_schemaorg.PetStore', 'PetStore'),
'BeautySalon': ('BeautySalon', 'pydantic_schemaorg.BeautySalon', 'BeautySalon'),
'SeeDoctorHealthAspect': ('SeeDoctorHealthAspect', 'pydantic_schemaorg.SeeDoctorHealthAspect', 'SeeDoctorHealthAspect'),
'NonprofitANBI': ('NonprofitANBI', 'pydantic_schemaorg.NonprofitANBI', 'NonprofitANBI'),
'DrugLegalStatus': ('DrugLegalStatus', 'pydantic_schemaorg.DrugLegalStatus', 'DrugLegalStatus'),
'SearchAction': ('SearchAction', 'pydantic_schemaorg.SearchAction', 'SearchAction'),
'Nonprofit527': ('Nonprofit527', 'pydantic_schemaorg.Nonprofit527', 'Nonprofit527'),
'DefinitiveLegalValue': ('DefinitiveLegalValue', 'pydantic_schemaorg.DefinitiveLegalValue', 'DefinitiveLegalValue'),
'SuperficialAnatomy': ('SuperficialAnatomy', 'pydantic_schemaorg.SuperficialAnatomy', 'SuperficialAnatomy'),
'SolveMathAction': ('SolveMathAction', 'pydantic_schemaorg.SolveMathAction', 'SolveMathAction'),
'Bacteria': ('Bacteria', 'pydantic_schemaorg.Bacteria', 'Bacteria'),
'Hematologic': ('Hematologic', 'pydantic_schemaorg.Hematologic', 'Hematologic'),
'Taxon': ('Taxon', 'pydantic_schemaorg.Taxon', 'Taxon'),
'SpokenWordAlbum': ('SpokenWordAlbum', 'pydantic_schemaorg.SpokenWordAlbum', 'SpokenWordAlbum'),
'GettingAccessHealthAspect': ('GettingAccessHealthAspect', 'pydantic_schemaorg.GettingAccessHealthAspect', 'GettingAccessHealthAspect'),
'LoanOrCredit': ('LoanOrCredit', 'pydantic_schemaorg.LoanOrCredit', 'LoanOrCredit'),
'CreditCard': ('CreditCard', 'pydantic_schemaorg.CreditCard', 'CreditCard'),
'BuddhistTemple': ('BuddhistTemple', 'pydantic_schemaorg.BuddhistTemple', 'BuddhistTemple'),
'WearableMeasurementHeight': ('WearableMeasurementHeight', 'pydantic_schemaorg.WearableMeasurementHeight', 'WearableMeasurementHeight'),
'DamagedCondition': ('DamagedCondition', 'pydantic_schemaorg.DamagedCondition', 'DamagedCondition'),
'Game': ('Game', 'pydantic_schemaorg.Game', 'Game'),
'DiagnosticProcedure': ('DiagnosticProcedure', 'pydantic_schemaorg.DiagnosticProcedure', 'DiagnosticProcedure'),
'Car': ('Car', 'pydantic_schemaorg.Car', 'Car'),
'Pathology': ('Pathology', 'pydantic_schemaorg.Pathology', 'Pathology'),
'Nonprofit501c23': ('Nonprofit501c23', 'pydantic_schemaorg.Nonprofit501c23', 'Nonprofit501c23'),
'Sculpture': ('Sculpture', 'pydantic_schemaorg.Sculpture', 'Sculpture'),
'Balance': ('Balance', 'pydantic_schemaorg.Balance', 'Balance'),
'VideoGameClip': ('VideoGameClip', 'pydantic_schemaorg.VideoGameClip', 'VideoGameClip'),
'DeliveryChargeSpecification': ('DeliveryChargeSpecification', 'pydantic_schemaorg.DeliveryChargeSpecification', 'DeliveryChargeSpecification'),
'FoodEstablishmentReservation': ('FoodEstablishmentReservation', 'pydantic_schemaorg.FoodEstablishmentReservation', 'FoodEstablishmentReservation'),
'Dataset': ('Dataset', 'pydantic_schemaorg.Dataset', 'Dataset'),
'DataFeed': ('DataFeed', 'pydantic_schemaorg.DataFeed', 'DataFeed'),
'CompleteDataFeed': ('CompleteDataFeed', 'pydantic_schemaorg.CompleteDataFeed', 'CompleteDataFeed'),
'DiscussionForumPosting': ('DiscussionForumPosting', 'pydantic_schemaorg.DiscussionForumPosting', 'DiscussionForumPosting'),
'PrognosisHealthAspect': ('PrognosisHealthAspect', 'pydantic_schemaorg.PrognosisHealthAspect', 'PrognosisHealthAspect'),
'MedicalProcedureType': ('MedicalProcedureType', 'pydantic_schemaorg.MedicalProcedureType', 'MedicalProcedureType'),
'NGO': ('NGO', 'pydantic_schemaorg.NGO', 'NGO'),
'Distance': ('Distance', 'pydantic_schemaorg.Distance', 'Distance'),
'LivingWithHealthAspect': ('LivingWithHealthAspect', 'pydantic_schemaorg.LivingWithHealthAspect', 'LivingWithHealthAspect'),
'PharmacySpecialty': ('PharmacySpecialty', 'pydantic_schemaorg.PharmacySpecialty', 'PharmacySpecialty'),
'EUEnergyEfficiencyCategoryA3Plus': ('EUEnergyEfficiencyCategoryA3Plus', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryA3Plus', 'EUEnergyEfficiencyCategoryA3Plus'),
'OrderProblem': ('OrderProblem', 'pydantic_schemaorg.OrderProblem', 'OrderProblem'),
'Airline': ('Airline', 'pydantic_schemaorg.Airline', 'Airline'),
'OfflineEventAttendanceMode': ('OfflineEventAttendanceMode', 'pydantic_schemaorg.OfflineEventAttendanceMode', 'OfflineEventAttendanceMode'),
'MedicalConditionStage': ('MedicalConditionStage', 'pydantic_schemaorg.MedicalConditionStage', 'MedicalConditionStage'),
'LimitedByGuaranteeCharity': ('LimitedByGuaranteeCharity', 'pydantic_schemaorg.LimitedByGuaranteeCharity', 'LimitedByGuaranteeCharity'),
'RisksOrComplicationsHealthAspect': ('RisksOrComplicationsHealthAspect', 'pydantic_schemaorg.RisksOrComplicationsHealthAspect', 'RisksOrComplicationsHealthAspect'),
'Church': ('Church', 'pydantic_schemaorg.Church', 'Church'),
'CatholicChurch': ('CatholicChurch', 'pydantic_schemaorg.CatholicChurch', 'CatholicChurch'),
'GeospatialGeometry': ('GeospatialGeometry', 'pydantic_schemaorg.GeospatialGeometry', 'GeospatialGeometry'),
'Muscle': ('Muscle', 'pydantic_schemaorg.Muscle', 'Muscle'),
'OpinionNewsArticle': ('OpinionNewsArticle', 'pydantic_schemaorg.OpinionNewsArticle', 'OpinionNewsArticle'),
'HowToItem': ('HowToItem', 'pydantic_schemaorg.HowToItem', 'HowToItem'),
'HowToTool': ('HowToTool', 'pydantic_schemaorg.HowToTool', 'HowToTool'),
'IceCreamShop': ('IceCreamShop', 'pydantic_schemaorg.IceCreamShop', 'IceCreamShop'),
'BusOrCoach': ('BusOrCoach', 'pydantic_schemaorg.BusOrCoach', 'BusOrCoach'),
'InvestmentOrDeposit': ('InvestmentOrDeposit', 'pydantic_schemaorg.InvestmentOrDeposit', 'InvestmentOrDeposit'),
'DepositAccount': ('DepositAccount', 'pydantic_schemaorg.DepositAccount', 'DepositAccount'),
'EditedOrCroppedContent': ('EditedOrCroppedContent', 'pydantic_schemaorg.EditedOrCroppedContent', 'EditedOrCroppedContent'),
'ParkingFacility': ('ParkingFacility', 'pydantic_schemaorg.ParkingFacility', 'ParkingFacility'),
'Recruiting': ('Recruiting', 'pydantic_schemaorg.Recruiting', 'Recruiting'),
'HowToTip': ('HowToTip', 'pydantic_schemaorg.HowToTip', 'HowToTip'),
'VideoGame': ('VideoGame', 'pydantic_schemaorg.VideoGame', 'VideoGame'),
'RentAction': ('RentAction', 'pydantic_schemaorg.RentAction', 'RentAction'),
'DJMixAlbum': ('DJMixAlbum', 'pydantic_schemaorg.DJMixAlbum', 'DJMixAlbum'),
'Nonprofit501n': ('Nonprofit501n', 'pydantic_schemaorg.Nonprofit501n', 'Nonprofit501n'),
'AmusementPark': ('AmusementPark', 'pydantic_schemaorg.AmusementPark', 'AmusementPark'),
'Nonprofit501c19': ('Nonprofit501c19', 'pydantic_schemaorg.Nonprofit501c19', 'Nonprofit501c19'),
'OriginalMediaContent': ('OriginalMediaContent', 'pydantic_schemaorg.OriginalMediaContent', 'OriginalMediaContent'),
'AudiobookFormat': ('AudiobookFormat', 'pydantic_schemaorg.AudiobookFormat', 'AudiobookFormat'),
'PatientExperienceHealthAspect': ('PatientExperienceHealthAspect', 'pydantic_schemaorg.PatientExperienceHealthAspect', 'PatientExperienceHealthAspect'),
'CreativeWorkSeason': ('CreativeWorkSeason', 'pydantic_schemaorg.CreativeWorkSeason', 'CreativeWorkSeason'),
'TVSeason': ('TVSeason', 'pydantic_schemaorg.TVSeason', 'TVSeason'),
'DrugPrescriptionStatus': ('DrugPrescriptionStatus', 'pydantic_schemaorg.DrugPrescriptionStatus', 'DrugPrescriptionStatus'),
'PrescriptionOnly': ('PrescriptionOnly', 'pydantic_schemaorg.PrescriptionOnly', 'PrescriptionOnly'),
'BusTrip': ('BusTrip', 'pydantic_schemaorg.BusTrip', 'BusTrip'),
'Time': ('Time', 'pydantic_schemaorg.Time', 'Time'),
'BedDetails': ('BedDetails', 'pydantic_schemaorg.BedDetails', 'BedDetails'),
'Suite': ('Suite', 'pydantic_schemaorg.Suite', 'Suite'),
'WearableSizeGroupGirls': ('WearableSizeGroupGirls', 'pydantic_schemaorg.WearableSizeGroupGirls', 'WearableSizeGroupGirls'),
'Subscription': ('Subscription', 'pydantic_schemaorg.Subscription', 'Subscription'),
'CategoryCodeSet': ('CategoryCodeSet', 'pydantic_schemaorg.CategoryCodeSet', 'CategoryCodeSet'),
'Lung': ('Lung', 'pydantic_schemaorg.Lung', 'Lung'),
'Nonprofit501c22': ('Nonprofit501c22', 'pydantic_schemaorg.Nonprofit501c22', 'Nonprofit501c22'),
'ProfessionalService': ('ProfessionalService', 'pydantic_schemaorg.ProfessionalService', 'ProfessionalService'),
'WebContent': ('WebContent', 'pydantic_schemaorg.WebContent', 'WebContent'),
'VideoGallery': ('VideoGallery', 'pydantic_schemaorg.VideoGallery', 'VideoGallery'),
'MerchantReturnFiniteReturnWindow': ('MerchantReturnFiniteReturnWindow', 'pydantic_schemaorg.MerchantReturnFiniteReturnWindow', 'MerchantReturnFiniteReturnWindow'),
'DrawAction': ('DrawAction', 'pydantic_schemaorg.DrawAction', 'DrawAction'),
'GroceryStore': ('GroceryStore', 'pydantic_schemaorg.GroceryStore', 'GroceryStore'),
'TVClip': ('TVClip', 'pydantic_schemaorg.TVClip', 'TVClip'),
'TouristAttraction': ('TouristAttraction', 'pydantic_schemaorg.TouristAttraction', 'TouristAttraction'),
'MediaSubscription': ('MediaSubscription', 'pydantic_schemaorg.MediaSubscription', 'MediaSubscription'),
'LiteraryEvent': ('LiteraryEvent', 'pydantic_schemaorg.LiteraryEvent', 'LiteraryEvent'),
'Photograph': ('Photograph', 'pydantic_schemaorg.Photograph', 'Photograph'),
'Role': ('Role', 'pydantic_schemaorg.Role', 'Role'),
'OrganizationRole': ('OrganizationRole', 'pydantic_schemaorg.OrganizationRole', 'OrganizationRole'),
'ReservationConfirmed': ('ReservationConfirmed', 'pydantic_schemaorg.ReservationConfirmed', 'ReservationConfirmed'),
'Hospital': ('Hospital', 'pydantic_schemaorg.Hospital', 'Hospital'),
'CDFormat': ('CDFormat', 'pydantic_schemaorg.CDFormat', 'CDFormat'),
'WearAction': ('WearAction', 'pydantic_schemaorg.WearAction', 'WearAction'),
'Rheumatologic': ('Rheumatologic', 'pydantic_schemaorg.Rheumatologic', 'Rheumatologic'),
'WPSideBar': ('WPSideBar', 'pydantic_schemaorg.WPSideBar', 'WPSideBar'),
'OccupationalTherapy': ('OccupationalTherapy', 'pydantic_schemaorg.OccupationalTherapy', 'OccupationalTherapy'),
'BefriendAction': ('BefriendAction', 'pydantic_schemaorg.BefriendAction', 'BefriendAction'),
'ItemListOrderDescending': ('ItemListOrderDescending', 'pydantic_schemaorg.ItemListOrderDescending', 'ItemListOrderDescending'),
'PostOffice': ('PostOffice', 'pydantic_schemaorg.PostOffice', 'PostOffice'),
'Winery': ('Winery', 'pydantic_schemaorg.Winery', 'Winery'),
'FilmAction': ('FilmAction', 'pydantic_schemaorg.FilmAction', 'FilmAction'),
'OrderPickupAvailable': ('OrderPickupAvailable', 'pydantic_schemaorg.OrderPickupAvailable', 'OrderPickupAvailable'),
'MobilePhoneStore': ('MobilePhoneStore', 'pydantic_schemaorg.MobilePhoneStore', 'MobilePhoneStore'),
'Landform': ('Landform', 'pydantic_schemaorg.Landform', 'Landform'),
'Continent': ('Continent', 'pydantic_schemaorg.Continent', 'Continent'),
'VitalSign': ('VitalSign', 'pydantic_schemaorg.VitalSign', 'VitalSign'),
'UserTweets': ('UserTweets', 'pydantic_schemaorg.UserTweets', 'UserTweets'),
'Observation': ('Observation', 'pydantic_schemaorg.Observation', 'Observation'),
'SubwayStation': ('SubwayStation', 'pydantic_schemaorg.SubwayStation', 'SubwayStation'),
'BroadcastService': ('BroadcastService', 'pydantic_schemaorg.BroadcastService', 'BroadcastService'),
'RadioBroadcastService': ('RadioBroadcastService', 'pydantic_schemaorg.RadioBroadcastService', 'RadioBroadcastService'),
'Legislation': ('Legislation', 'pydantic_schemaorg.Legislation', 'Legislation'),
'BoardingPolicyType': ('BoardingPolicyType', 'pydantic_schemaorg.BoardingPolicyType', 'BoardingPolicyType'),
'GroupBoardingPolicy': ('GroupBoardingPolicy', 'pydantic_schemaorg.GroupBoardingPolicy', 'GroupBoardingPolicy'),
'DrugClass': ('DrugClass', 'pydantic_schemaorg.DrugClass', 'DrugClass'),
'Motorcycle': ('Motorcycle', 'pydantic_schemaorg.Motorcycle', 'Motorcycle'),
'Pulmonary': ('Pulmonary', 'pydantic_schemaorg.Pulmonary', 'Pulmonary'),
'MovieClip': ('MovieClip', 'pydantic_schemaorg.MovieClip', 'MovieClip'),
'LymphaticVessel': ('LymphaticVessel', 'pydantic_schemaorg.LymphaticVessel', 'LymphaticVessel'),
'FundingAgency': ('FundingAgency', 'pydantic_schemaorg.FundingAgency', 'FundingAgency'),
'MortgageLoan': ('MortgageLoan', 'pydantic_schemaorg.MortgageLoan', 'MortgageLoan'),
'SpeakableSpecification': ('SpeakableSpecification', 'pydantic_schemaorg.SpeakableSpecification', 'SpeakableSpecification'),
'RestockingFees': ('RestockingFees', 'pydantic_schemaorg.RestockingFees', 'RestockingFees'),
'ServiceChannel': ('ServiceChannel', 'pydantic_schemaorg.ServiceChannel', 'ServiceChannel'),
'ImageGallery': ('ImageGallery', 'pydantic_schemaorg.ImageGallery', 'ImageGallery'),
'TypeAndQuantityNode': ('TypeAndQuantityNode', 'pydantic_schemaorg.TypeAndQuantityNode', 'TypeAndQuantityNode'),
'AdultEntertainment': ('AdultEntertainment', 'pydantic_schemaorg.AdultEntertainment', 'AdultEntertainment'),
'MotorcycleRepair': ('MotorcycleRepair', 'pydantic_schemaorg.MotorcycleRepair', 'MotorcycleRepair'),
'WearableMeasurementSleeve': ('WearableMeasurementSleeve', 'pydantic_schemaorg.WearableMeasurementSleeve', 'WearableMeasurementSleeve'),
'RsvpResponseYes': ('RsvpResponseYes', 'pydantic_schemaorg.RsvpResponseYes', 'RsvpResponseYes'),
'CommentAction': ('CommentAction', 'pydantic_schemaorg.CommentAction', 'CommentAction'),
'City': ('City', 'pydantic_schemaorg.City', 'City'),
'InternetCafe': ('InternetCafe', 'pydantic_schemaorg.InternetCafe', 'InternetCafe'),
'PreventionHealthAspect': ('PreventionHealthAspect', 'pydantic_schemaorg.PreventionHealthAspect', 'PreventionHealthAspect'),
'Renal': ('Renal', 'pydantic_schemaorg.Renal', 'Renal'),
'TreatmentsHealthAspect': ('TreatmentsHealthAspect', 'pydantic_schemaorg.TreatmentsHealthAspect', 'TreatmentsHealthAspect'),
'Festival': ('Festival', 'pydantic_schemaorg.Festival', 'Festival'),
'GeoCoordinates': ('GeoCoordinates', 'pydantic_schemaorg.GeoCoordinates', 'GeoCoordinates'),
'VegetarianDiet': ('VegetarianDiet', 'pydantic_schemaorg.VegetarianDiet', 'VegetarianDiet'),
'RepaymentSpecification': ('RepaymentSpecification', 'pydantic_schemaorg.RepaymentSpecification', 'RepaymentSpecification'),
'Motel': ('Motel', 'pydantic_schemaorg.Motel', 'Motel'),
'CaseSeries': ('CaseSeries', 'pydantic_schemaorg.CaseSeries', 'CaseSeries'),
'ReportageNewsArticle': ('ReportageNewsArticle', 'pydantic_schemaorg.ReportageNewsArticle', 'ReportageNewsArticle'),
'Optometric': ('Optometric', 'pydantic_schemaorg.Optometric', 'Optometric'),
'EventReservation': ('EventReservation', 'pydantic_schemaorg.EventReservation', 'EventReservation'),
'QuoteAction': ('QuoteAction', 'pydantic_schemaorg.QuoteAction', 'QuoteAction'),
'PublicationVolume': ('PublicationVolume', 'pydantic_schemaorg.PublicationVolume', 'PublicationVolume'),
'RVPark': ('RVPark', 'pydantic_schemaorg.RVPark', 'RVPark'),
'Downpayment': ('Downpayment', 'pydantic_schemaorg.Downpayment', 'Downpayment'),
'StoreCreditRefund': ('StoreCreditRefund', 'pydantic_schemaorg.StoreCreditRefund', 'StoreCreditRefund'),
'ResultsAvailable': ('ResultsAvailable', 'pydantic_schemaorg.ResultsAvailable', 'ResultsAvailable'),
'AgreeAction': ('AgreeAction', 'pydantic_schemaorg.AgreeAction', 'AgreeAction'),
'JewelryStore': ('JewelryStore', 'pydantic_schemaorg.JewelryStore', 'JewelryStore'),
'Ligament': ('Ligament', 'pydantic_schemaorg.Ligament', 'Ligament'),
'AnimalShelter': ('AnimalShelter', 'pydantic_schemaorg.AnimalShelter', 'AnimalShelter'),
'SpecialAnnouncement': ('SpecialAnnouncement', 'pydantic_schemaorg.SpecialAnnouncement', 'SpecialAnnouncement'),
'TransitMap': ('TransitMap', 'pydantic_schemaorg.TransitMap', 'TransitMap'),
'ReturnAction': ('ReturnAction', 'pydantic_schemaorg.ReturnAction', 'ReturnAction'),
'Hardcover': ('Hardcover', 'pydantic_schemaorg.Hardcover', 'Hardcover'),
'Atlas': ('Atlas', 'pydantic_schemaorg.Atlas', 'Atlas'),
'Drawing': ('Drawing', 'pydantic_schemaorg.Drawing', 'Drawing'),
'FDAcategoryA': ('FDAcategoryA', 'pydantic_schemaorg.FDAcategoryA', 'FDAcategoryA'),
'EventPostponed': ('EventPostponed', 'pydantic_schemaorg.EventPostponed', 'EventPostponed'),
'ChemicalSubstance': ('ChemicalSubstance', 'pydantic_schemaorg.ChemicalSubstance', 'ChemicalSubstance'),
'Restaurant': ('Restaurant', 'pydantic_schemaorg.Restaurant', 'Restaurant'),
'ProductGroup': ('ProductGroup', 'pydantic_schemaorg.ProductGroup', 'ProductGroup'),
'ShippingDeliveryTime': ('ShippingDeliveryTime', 'pydantic_schemaorg.ShippingDeliveryTime', 'ShippingDeliveryTime'),
'WearableSizeGroupShort': ('WearableSizeGroupShort', 'pydantic_schemaorg.WearableSizeGroupShort', 'WearableSizeGroupShort'),
'Table': ('Table', 'pydantic_schemaorg.Table', 'Table'),
'ActiveNotRecruiting': ('ActiveNotRecruiting', 'pydantic_schemaorg.ActiveNotRecruiting', 'ActiveNotRecruiting'),
'MRI': ('MRI', 'pydantic_schemaorg.MRI', 'MRI'),
'MSRP': ('MSRP', 'pydantic_schemaorg.MSRP', 'MSRP'),
'SoundtrackAlbum': ('SoundtrackAlbum', 'pydantic_schemaorg.SoundtrackAlbum', 'SoundtrackAlbum'),
'BorrowAction': ('BorrowAction', 'pydantic_schemaorg.BorrowAction', 'BorrowAction'),
'CriticReview': ('CriticReview', 'pydantic_schemaorg.CriticReview', 'CriticReview'),
'ReviewNewsArticle': ('ReviewNewsArticle', 'pydantic_schemaorg.ReviewNewsArticle', 'ReviewNewsArticle'),
'HotelRoom': ('HotelRoom', 'pydantic_schemaorg.HotelRoom', 'HotelRoom'),
'WearableMeasurementWaist': ('WearableMeasurementWaist', 'pydantic_schemaorg.WearableMeasurementWaist', 'WearableMeasurementWaist'),
'ArchiveOrganization': ('ArchiveOrganization', 'pydantic_schemaorg.ArchiveOrganization', 'ArchiveOrganization'),
'Claim': ('Claim', 'pydantic_schemaorg.Claim', 'Claim'),
'ProgramMembership': ('ProgramMembership', 'pydantic_schemaorg.ProgramMembership', 'ProgramMembership'),
'Barcode': ('Barcode', 'pydantic_schemaorg.Barcode', 'Barcode'),
'Nonprofit501a': ('Nonprofit501a', 'pydantic_schemaorg.Nonprofit501a', 'Nonprofit501a'),
'WearableSizeSystemJP': ('WearableSizeSystemJP', 'pydantic_schemaorg.WearableSizeSystemJP', 'WearableSizeSystemJP'),
'DatedMoneySpecification': ('DatedMoneySpecification', 'pydantic_schemaorg.DatedMoneySpecification', 'DatedMoneySpecification'),
'OnDemandEvent': ('OnDemandEvent', 'pydantic_schemaorg.OnDemandEvent', 'OnDemandEvent'),
'ArtGallery': ('ArtGallery', 'pydantic_schemaorg.ArtGallery', 'ArtGallery'),
'OrderItem': ('OrderItem', 'pydantic_schemaorg.OrderItem', 'OrderItem'),
'HowToSupply': ('HowToSupply', 'pydantic_schemaorg.HowToSupply', 'HowToSupply'),
'ShoppingCenter': ('ShoppingCenter', 'pydantic_schemaorg.ShoppingCenter', 'ShoppingCenter'),
'Sunday': ('Sunday', 'pydantic_schemaorg.Sunday', 'Sunday'),
'PsychologicalTreatment': ('PsychologicalTreatment', 'pydantic_schemaorg.PsychologicalTreatment', 'PsychologicalTreatment'),
'DoubleBlindedTrial': ('DoubleBlindedTrial', 'pydantic_schemaorg.DoubleBlindedTrial', 'DoubleBlindedTrial'),
'GiveAction': ('GiveAction', 'pydantic_schemaorg.GiveAction', 'GiveAction'),
'ResearchOrganization': ('ResearchOrganization', 'pydantic_schemaorg.ResearchOrganization', 'ResearchOrganization'),
'CT': ('CT', 'pydantic_schemaorg.CT', 'CT'),
'EndorsementRating': ('EndorsementRating', 'pydantic_schemaorg.EndorsementRating', 'EndorsementRating'),
'BodyOfWater': ('BodyOfWater', 'pydantic_schemaorg.BodyOfWater', 'BodyOfWater'),
'RiverBodyOfWater': ('RiverBodyOfWater', 'pydantic_schemaorg.RiverBodyOfWater', 'RiverBodyOfWater'),
'TouristInformationCenter': ('TouristInformationCenter', 'pydantic_schemaorg.TouristInformationCenter', 'TouristInformationCenter'),
'HousePainter': ('HousePainter', 'pydantic_schemaorg.HousePainter', 'HousePainter'),
'BodyMeasurementArm': ('BodyMeasurementArm', 'pydantic_schemaorg.BodyMeasurementArm', 'BodyMeasurementArm'),
'TextDigitalDocument': ('TextDigitalDocument', 'pydantic_schemaorg.TextDigitalDocument', 'TextDigitalDocument'),
'DislikeAction': ('DislikeAction', 'pydantic_schemaorg.DislikeAction', 'DislikeAction'),
'VoteAction': ('VoteAction', 'pydantic_schemaorg.VoteAction', 'VoteAction'),
'PreOrder': ('PreOrder', 'pydantic_schemaorg.PreOrder', 'PreOrder'),
'PawnShop': ('PawnShop', 'pydantic_schemaorg.PawnShop', 'PawnShop'),
'LegislationObject': ('LegislationObject', 'pydantic_schemaorg.LegislationObject', 'LegislationObject'),
'WearableMeasurementWidth': ('WearableMeasurementWidth', 'pydantic_schemaorg.WearableMeasurementWidth', 'WearableMeasurementWidth'),
'Prion': ('Prion', 'pydantic_schemaorg.Prion', 'Prion'),
'FailedActionStatus': ('FailedActionStatus', 'pydantic_schemaorg.FailedActionStatus', 'FailedActionStatus'),
'KosherDiet': ('KosherDiet', 'pydantic_schemaorg.KosherDiet', 'KosherDiet'),
'RealEstateListing': ('RealEstateListing', 'pydantic_schemaorg.RealEstateListing', 'RealEstateListing'),
'EducationalAudience': ('EducationalAudience', 'pydantic_schemaorg.EducationalAudience', 'EducationalAudience'),
'OTC': ('OTC', 'pydantic_schemaorg.OTC', 'OTC'),
'SizeSpecification': ('SizeSpecification', 'pydantic_schemaorg.SizeSpecification', 'SizeSpecification'),
'Chapter': ('Chapter', 'pydantic_schemaorg.Chapter', 'Chapter'),
'Wednesday': ('Wednesday', 'pydantic_schemaorg.Wednesday', 'Wednesday'),
'EventVenue': ('EventVenue', 'pydantic_schemaorg.EventVenue', 'EventVenue'),
'PotentialActionStatus': ('PotentialActionStatus', 'pydantic_schemaorg.PotentialActionStatus', 'PotentialActionStatus'),
'PublicSwimmingPool': ('PublicSwimmingPool', 'pydantic_schemaorg.PublicSwimmingPool', 'PublicSwimmingPool'),
'BodyMeasurementHand': ('BodyMeasurementHand', 'pydantic_schemaorg.BodyMeasurementHand', 'BodyMeasurementHand'),
'WearableSizeSystemDE': ('WearableSizeSystemDE', 'pydantic_schemaorg.WearableSizeSystemDE', 'WearableSizeSystemDE'),
'ContactPage': ('ContactPage', 'pydantic_schemaorg.ContactPage', 'ContactPage'),
'VideoObject': ('VideoObject', 'pydantic_schemaorg.VideoObject', 'VideoObject'),
'VideoObjectSnapshot': ('VideoObjectSnapshot', 'pydantic_schemaorg.VideoObjectSnapshot', 'VideoObjectSnapshot'),
'VirtualLocation': ('VirtualLocation', 'pydantic_schemaorg.VirtualLocation', 'VirtualLocation'),
'Pond': ('Pond', 'pydantic_schemaorg.Pond', 'Pond'),
'ListPrice': ('ListPrice', 'pydantic_schemaorg.ListPrice', 'ListPrice'),
'UserCheckins': ('UserCheckins', 'pydantic_schemaorg.UserCheckins', 'UserCheckins'),
'IngredientsHealthAspect': ('IngredientsHealthAspect', 'pydantic_schemaorg.IngredientsHealthAspect', 'IngredientsHealthAspect'),
'EmailMessage': ('EmailMessage', 'pydantic_schemaorg.EmailMessage', 'EmailMessage'),
'PeopleAudience': ('PeopleAudience', 'pydantic_schemaorg.PeopleAudience', 'PeopleAudience'),
'SeaBodyOfWater': ('SeaBodyOfWater', 'pydantic_schemaorg.SeaBodyOfWater', 'SeaBodyOfWater'),
'HowItWorksHealthAspect': ('HowItWorksHealthAspect', 'pydantic_schemaorg.HowItWorksHealthAspect', 'HowItWorksHealthAspect'),
'AutoDealer': ('AutoDealer', 'pydantic_schemaorg.AutoDealer', 'AutoDealer'),
'HealthInsurancePlan': ('HealthInsurancePlan', 'pydantic_schemaorg.HealthInsurancePlan', 'HealthInsurancePlan'),
'CollegeOrUniversity': ('CollegeOrUniversity', 'pydantic_schemaorg.CollegeOrUniversity', 'CollegeOrUniversity'),
'ResumeAction': ('ResumeAction', 'pydantic_schemaorg.ResumeAction', 'ResumeAction'),
'MerchantReturnUnspecified': ('MerchantReturnUnspecified', 'pydantic_schemaorg.MerchantReturnUnspecified', 'MerchantReturnUnspecified'),
'CheckAction': ('CheckAction', 'pydantic_schemaorg.CheckAction', 'CheckAction'),
'StatisticalPopulation': ('StatisticalPopulation', 'pydantic_schemaorg.StatisticalPopulation', 'StatisticalPopulation'),
'WearableSizeSystemAU': ('WearableSizeSystemAU', 'pydantic_schemaorg.WearableSizeSystemAU', 'WearableSizeSystemAU'),
'LowCalorieDiet': ('LowCalorieDiet', 'pydantic_schemaorg.LowCalorieDiet', 'LowCalorieDiet'),
'State': ('State', 'pydantic_schemaorg.State', 'State'),
'PodcastEpisode': ('PodcastEpisode', 'pydantic_schemaorg.PodcastEpisode', 'PodcastEpisode'),
'UserLikes': ('UserLikes', 'pydantic_schemaorg.UserLikes', 'UserLikes'),
'WPAdBlock': ('WPAdBlock', 'pydantic_schemaorg.WPAdBlock', 'WPAdBlock'),
'TouristDestination': ('TouristDestination', 'pydantic_schemaorg.TouristDestination', 'TouristDestination'),
'Beach': ('Beach', 'pydantic_schemaorg.Beach', 'Beach'),
'TrainStation': ('TrainStation', 'pydantic_schemaorg.TrainStation', 'TrainStation'),
'LakeBodyOfWater': ('LakeBodyOfWater', 'pydantic_schemaorg.LakeBodyOfWater', 'LakeBodyOfWater'),
'DecontextualizedContent': ('DecontextualizedContent', 'pydantic_schemaorg.DecontextualizedContent', 'DecontextualizedContent'),
'CompilationAlbum': ('CompilationAlbum', 'pydantic_schemaorg.CompilationAlbum', 'CompilationAlbum'),
'CampingPitch': ('CampingPitch', 'pydantic_schemaorg.CampingPitch', 'CampingPitch'),
'TieAction': ('TieAction', 'pydantic_schemaorg.TieAction', 'TieAction'),
'Toxicologic': ('Toxicologic', 'pydantic_schemaorg.Toxicologic', 'Toxicologic'),
'GeneralContractor': ('GeneralContractor', 'pydantic_schemaorg.GeneralContractor', 'GeneralContractor'),
'MedicalRiskScore': ('MedicalRiskScore', 'pydantic_schemaorg.MedicalRiskScore', 'MedicalRiskScore'),
'OnlineFull': ('OnlineFull', 'pydantic_schemaorg.OnlineFull', 'OnlineFull'),
'PreOrderAction': ('PreOrderAction', 'pydantic_schemaorg.PreOrderAction', 'PreOrderAction'),
'ItemListOrderAscending': ('ItemListOrderAscending', 'pydantic_schemaorg.ItemListOrderAscending', 'ItemListOrderAscending'),
'InternationalTrial': ('InternationalTrial', 'pydantic_schemaorg.InternationalTrial', 'InternationalTrial'),
'NoteDigitalDocument': ('NoteDigitalDocument', 'pydantic_schemaorg.NoteDigitalDocument', 'NoteDigitalDocument'),
'CssSelectorType': ('CssSelectorType', 'pydantic_schemaorg.CssSelectorType', 'CssSelectorType'),
'WarrantyScope': ('WarrantyScope', 'pydantic_schemaorg.WarrantyScope', 'WarrantyScope'),
'Neurologic': ('Neurologic', 'pydantic_schemaorg.Neurologic', 'Neurologic'),
'PodcastSeries': ('PodcastSeries', 'pydantic_schemaorg.PodcastSeries', 'PodcastSeries'),
'Property': ('Property', 'pydantic_schemaorg.Property', 'Property'),
'PublicToilet': ('PublicToilet', 'pydantic_schemaorg.PublicToilet', 'PublicToilet'),
'MedicalAudience': ('MedicalAudience', 'pydantic_schemaorg.MedicalAudience', 'MedicalAudience'),
'LaboratoryScience': ('LaboratoryScience', 'pydantic_schemaorg.LaboratoryScience', 'LaboratoryScience'),
'AllergiesHealthAspect': ('AllergiesHealthAspect', 'pydantic_schemaorg.AllergiesHealthAspect', 'AllergiesHealthAspect'),
'ReplyAction': ('ReplyAction', 'pydantic_schemaorg.ReplyAction', 'ReplyAction'),
'ConvenienceStore': ('ConvenienceStore', 'pydantic_schemaorg.ConvenienceStore', 'ConvenienceStore'),
'UserPageVisits': ('UserPageVisits', 'pydantic_schemaorg.UserPageVisits', 'UserPageVisits'),
'OutletStore': ('OutletStore', 'pydantic_schemaorg.OutletStore', 'OutletStore'),
'ReplaceAction': ('ReplaceAction', 'pydantic_schemaorg.ReplaceAction', 'ReplaceAction'),
'AutomatedTeller': ('AutomatedTeller', 'pydantic_schemaorg.AutomatedTeller', 'AutomatedTeller'),
'ApplyAction': ('ApplyAction', 'pydantic_schemaorg.ApplyAction', 'ApplyAction'),
'MusicGroup': ('MusicGroup', 'pydantic_schemaorg.MusicGroup', 'MusicGroup'),
'ItemPage': ('ItemPage', 'pydantic_schemaorg.ItemPage', 'ItemPage'),
'HardwareStore': ('HardwareStore', 'pydantic_schemaorg.HardwareStore', 'HardwareStore'),
'UnemploymentSupport': ('UnemploymentSupport', 'pydantic_schemaorg.UnemploymentSupport', 'UnemploymentSupport'),
'MedicalRiskCalculator': ('MedicalRiskCalculator', 'pydantic_schemaorg.MedicalRiskCalculator', 'MedicalRiskCalculator'),
'Locksmith': ('Locksmith', 'pydantic_schemaorg.Locksmith', 'Locksmith'),
'ActiveActionStatus': ('ActiveActionStatus', 'pydantic_schemaorg.ActiveActionStatus', 'ActiveActionStatus'),
'AudioObjectSnapshot': ('AudioObjectSnapshot', 'pydantic_schemaorg.AudioObjectSnapshot', 'AudioObjectSnapshot'),
'ReturnInStore': ('ReturnInStore', 'pydantic_schemaorg.ReturnInStore', 'ReturnInStore'),
'SeekToAction': ('SeekToAction', 'pydantic_schemaorg.SeekToAction', 'SeekToAction'),
'MedicalGuideline': ('MedicalGuideline', 'pydantic_schemaorg.MedicalGuideline', 'MedicalGuideline'),
'MedicalGuidelineRecommendation': ('MedicalGuidelineRecommendation', 'pydantic_schemaorg.MedicalGuidelineRecommendation', 'MedicalGuidelineRecommendation'),
'TattooParlor': ('TattooParlor', 'pydantic_schemaorg.TattooParlor', 'TattooParlor'),
'DonateAction': ('DonateAction', 'pydantic_schemaorg.DonateAction', 'DonateAction'),
'UsageOrScheduleHealthAspect': ('UsageOrScheduleHealthAspect', 'pydantic_schemaorg.UsageOrScheduleHealthAspect', 'UsageOrScheduleHealthAspect'),
'Guide': ('Guide', 'pydantic_schemaorg.Guide', 'Guide'),
'BoatTerminal': ('BoatTerminal', 'pydantic_schemaorg.BoatTerminal', 'BoatTerminal'),
'VeganDiet': ('VeganDiet', 'pydantic_schemaorg.VeganDiet', 'VeganDiet'),
'Nonprofit501c6': ('Nonprofit501c6', 'pydantic_schemaorg.Nonprofit501c6', 'Nonprofit501c6'),
'PublicHolidays': ('PublicHolidays', 'pydantic_schemaorg.PublicHolidays', 'PublicHolidays'),
'Cardiovascular': ('Cardiovascular', 'pydantic_schemaorg.Cardiovascular', 'Cardiovascular'),
'IndividualProduct': ('IndividualProduct', 'pydantic_schemaorg.IndividualProduct', 'IndividualProduct'),
'MusculoskeletalExam': ('MusculoskeletalExam', 'pydantic_schemaorg.MusculoskeletalExam', 'MusculoskeletalExam'),
'MotorizedBicycle': ('MotorizedBicycle', 'pydantic_schemaorg.MotorizedBicycle', 'MotorizedBicycle'),
'OfflinePermanently': ('OfflinePermanently', 'pydantic_schemaorg.OfflinePermanently', 'OfflinePermanently'),
'AggregateOffer': ('AggregateOffer', 'pydantic_schemaorg.AggregateOffer', 'AggregateOffer'),
'Poster': ('Poster', 'pydantic_schemaorg.Poster', 'Poster'),
'CourseInstance': ('CourseInstance', 'pydantic_schemaorg.CourseInstance', 'CourseInstance'),
'FDAcategoryC': ('FDAcategoryC', 'pydantic_schemaorg.FDAcategoryC', 'FDAcategoryC'),
'FourWheelDriveConfiguration': ('FourWheelDriveConfiguration', 'pydantic_schemaorg.FourWheelDriveConfiguration', 'FourWheelDriveConfiguration'),
'ReturnByMail': ('ReturnByMail', 'pydantic_schemaorg.ReturnByMail', 'ReturnByMail'),
'EducationEvent': ('EducationEvent', 'pydantic_schemaorg.EducationEvent', 'EducationEvent'),
'MisconceptionsHealthAspect': ('MisconceptionsHealthAspect', 'pydantic_schemaorg.MisconceptionsHealthAspect', 'MisconceptionsHealthAspect'),
'BedType': ('BedType', 'pydantic_schemaorg.BedType', 'BedType'),
'MedicalClinic': ('MedicalClinic', 'pydantic_schemaorg.MedicalClinic', 'MedicalClinic'),
'CovidTestingFacility': ('CovidTestingFacility', 'pydantic_schemaorg.CovidTestingFacility', 'CovidTestingFacility'),
'WearableSizeGroupExtraShort': ('WearableSizeGroupExtraShort', 'pydantic_schemaorg.WearableSizeGroupExtraShort', 'WearableSizeGroupExtraShort'),
'FurnitureStore': ('FurnitureStore', 'pydantic_schemaorg.FurnitureStore', 'FurnitureStore'),
'PodcastSeason': ('PodcastSeason', 'pydantic_schemaorg.PodcastSeason', 'PodcastSeason'),
'CDCPMDRecord': ('CDCPMDRecord', 'pydantic_schemaorg.CDCPMDRecord', 'CDCPMDRecord'),
'HobbyShop': ('HobbyShop', 'pydantic_schemaorg.HobbyShop', 'HobbyShop'),
'WearableSizeSystemEurope': ('WearableSizeSystemEurope', 'pydantic_schemaorg.WearableSizeSystemEurope', 'WearableSizeSystemEurope'),
'Mosque': ('Mosque', 'pydantic_schemaorg.Mosque', 'Mosque'),
'Radiography': ('Radiography', 'pydantic_schemaorg.Radiography', 'Radiography'),
'OrderReturned': ('OrderReturned', 'pydantic_schemaorg.OrderReturned', 'OrderReturned'),
'PaintAction': ('PaintAction', 'pydantic_schemaorg.PaintAction', 'PaintAction'),
'Midwifery': ('Midwifery', 'pydantic_schemaorg.Midwifery', 'Midwifery'),
'WearableMeasurementInseam': ('WearableMeasurementInseam', 'pydantic_schemaorg.WearableMeasurementInseam', 'WearableMeasurementInseam'),
'OnSitePickup': ('OnSitePickup', 'pydantic_schemaorg.OnSitePickup', 'OnSitePickup'),
'Completed': ('Completed', 'pydantic_schemaorg.Completed', 'Completed'),
'SinglePlayer': ('SinglePlayer', 'pydantic_schemaorg.SinglePlayer', 'SinglePlayer'),
'OnlineEventAttendanceMode': ('OnlineEventAttendanceMode', 'pydantic_schemaorg.OnlineEventAttendanceMode', 'OnlineEventAttendanceMode'),
'ReportedDoseSchedule': ('ReportedDoseSchedule', 'pydantic_schemaorg.ReportedDoseSchedule', 'ReportedDoseSchedule'),
'FullRefund': ('FullRefund', 'pydantic_schemaorg.FullRefund', 'FullRefund'),
'PropertyValueSpecification': ('PropertyValueSpecification', 'pydantic_schemaorg.PropertyValueSpecification', 'PropertyValueSpecification'),
'Boolean': ('Boolean', 'pydantic_schemaorg.Boolean', 'Boolean'),
'False_': ('False_', 'pydantic_schemaorg.False_', 'False_'),
'ElectronicsStore': ('ElectronicsStore', 'pydantic_schemaorg.ElectronicsStore', 'ElectronicsStore'),
'Language': ('Language', 'pydantic_schemaorg.Language', 'Language'),
'InStock': ('InStock', 'pydantic_schemaorg.InStock', 'InStock'),
'AccountingService': ('AccountingService', 'pydantic_schemaorg.AccountingService', 'AccountingService'),
'WearableSizeGroupBig': ('WearableSizeGroupBig', 'pydantic_schemaorg.WearableSizeGroupBig', 'WearableSizeGroupBig'),
'ParcelService': ('ParcelService', 'pydantic_schemaorg.ParcelService', 'ParcelService'),
'MerchantReturnUnlimitedWindow': ('MerchantReturnUnlimitedWindow', 'pydantic_schemaorg.MerchantReturnUnlimitedWindow', 'MerchantReturnUnlimitedWindow'),
'ExchangeRateSpecification': ('ExchangeRateSpecification', 'pydantic_schemaorg.ExchangeRateSpecification', 'ExchangeRateSpecification'),
'ResultsNotAvailable': ('ResultsNotAvailable', 'pydantic_schemaorg.ResultsNotAvailable', 'ResultsNotAvailable'),
'PoliceStation': ('PoliceStation', 'pydantic_schemaorg.PoliceStation', 'PoliceStation'),
'Otolaryngologic': ('Otolaryngologic', 'pydantic_schemaorg.Otolaryngologic', 'Otolaryngologic'),
'Longitudinal': ('Longitudinal', 'pydantic_schemaorg.Longitudinal', 'Longitudinal'),
'ComputerLanguage': ('ComputerLanguage', 'pydantic_schemaorg.ComputerLanguage', 'ComputerLanguage'),
'DepartAction': ('DepartAction', 'pydantic_schemaorg.DepartAction', 'DepartAction'),
'PET': ('PET', 'pydantic_schemaorg.PET', 'PET'),
'Neuro': ('Neuro', 'pydantic_schemaorg.Neuro', 'Neuro'),
'MedicalResearcher': ('MedicalResearcher', 'pydantic_schemaorg.MedicalResearcher', 'MedicalResearcher'),
'WebSite': ('WebSite', 'pydantic_schemaorg.WebSite', 'WebSite'),
'ShippingRateSettings': ('ShippingRateSettings', 'pydantic_schemaorg.ShippingRateSettings', 'ShippingRateSettings'),
'EndorseAction': ('EndorseAction', 'pydantic_schemaorg.EndorseAction', 'EndorseAction'),
'Tuesday': ('Tuesday', 'pydantic_schemaorg.Tuesday', 'Tuesday'),
'WPFooter': ('WPFooter', 'pydantic_schemaorg.WPFooter', 'WPFooter'),
'Patient': ('Patient', 'pydantic_schemaorg.Patient', 'Patient'),
'FMRadioChannel': ('FMRadioChannel', 'pydantic_schemaorg.FMRadioChannel', 'FMRadioChannel'),
'HealthCare': ('HealthCare', 'pydantic_schemaorg.HealthCare', 'HealthCare'),
'Female': ('Female', 'pydantic_schemaorg.Female', 'Female'),
'InsuranceAgency': ('InsuranceAgency', 'pydantic_schemaorg.InsuranceAgency', 'InsuranceAgency'),
'ReturnLabelCustomerResponsibility': ('ReturnLabelCustomerResponsibility', 'pydantic_schemaorg.ReturnLabelCustomerResponsibility', 'ReturnLabelCustomerResponsibility'),
'DanceGroup': ('DanceGroup', 'pydantic_schemaorg.DanceGroup', 'DanceGroup'),
'MedicalDevice': ('MedicalDevice', 'pydantic_schemaorg.MedicalDevice', 'MedicalDevice'),
'BodyMeasurementFoot': ('BodyMeasurementFoot', 'pydantic_schemaorg.BodyMeasurementFoot', 'BodyMeasurementFoot'),
'DDxElement': ('DDxElement', 'pydantic_schemaorg.DDxElement', 'DDxElement'),
'TaxiStand': ('TaxiStand', 'pydantic_schemaorg.TaxiStand', 'TaxiStand'),
'FloorPlan': ('FloorPlan', 'pydantic_schemaorg.FloorPlan', 'FloorPlan'),
'InviteAction': ('InviteAction', 'pydantic_schemaorg.InviteAction', 'InviteAction'),
'Genitourinary': ('Genitourinary', 'pydantic_schemaorg.Genitourinary', 'Genitourinary'),
'EmployeeRole': ('EmployeeRole', 'pydantic_schemaorg.EmployeeRole', 'EmployeeRole'),
'PregnancyHealthAspect': ('PregnancyHealthAspect', 'pydantic_schemaorg.PregnancyHealthAspect', 'PregnancyHealthAspect'),
'HealthPlanCostSharingSpecification': ('HealthPlanCostSharingSpecification', 'pydantic_schemaorg.HealthPlanCostSharingSpecification', 'HealthPlanCostSharingSpecification'),
'Eye': ('Eye', 'pydantic_schemaorg.Eye', 'Eye'),
'MerchantReturnPolicySeasonalOverride': ('MerchantReturnPolicySeasonalOverride', 'pydantic_schemaorg.MerchantReturnPolicySeasonalOverride', 'MerchantReturnPolicySeasonalOverride'),
'Homeopathic': ('Homeopathic', 'pydantic_schemaorg.Homeopathic', 'Homeopathic'),
'DeleteAction': ('DeleteAction', 'pydantic_schemaorg.DeleteAction', 'DeleteAction'),
'Attorney': ('Attorney', 'pydantic_schemaorg.Attorney', 'Attorney'),
'MensClothingStore': ('MensClothingStore', 'pydantic_schemaorg.MensClothingStore', 'MensClothingStore'),
'AutoWash': ('AutoWash', 'pydantic_schemaorg.AutoWash', 'AutoWash'),
'ReceiveAction': ('ReceiveAction', 'pydantic_schemaorg.ReceiveAction', 'ReceiveAction'),
'EUEnergyEfficiencyCategoryF': ('EUEnergyEfficiencyCategoryF', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryF', 'EUEnergyEfficiencyCategoryF'),
'NotInForce': ('NotInForce', 'pydantic_schemaorg.NotInForce', 'NotInForce'),
'MovieSeries': ('MovieSeries', 'pydantic_schemaorg.MovieSeries', 'MovieSeries'),
'Discontinued': ('Discontinued', 'pydantic_schemaorg.Discontinued', 'Discontinued'),
'LodgingReservation': ('LodgingReservation', 'pydantic_schemaorg.LodgingReservation', 'LodgingReservation'),
'LiveAlbum': ('LiveAlbum', 'pydantic_schemaorg.LiveAlbum', 'LiveAlbum'),
'Invoice': ('Invoice', 'pydantic_schemaorg.Invoice', 'Invoice'),
'SportingGoodsStore': ('SportingGoodsStore', 'pydantic_schemaorg.SportingGoodsStore', 'SportingGoodsStore'),
'CafeOrCoffeeShop': ('CafeOrCoffeeShop', 'pydantic_schemaorg.CafeOrCoffeeShop', 'CafeOrCoffeeShop'),
'WearableSizeSystemIT': ('WearableSizeSystemIT', 'pydantic_schemaorg.WearableSizeSystemIT', 'WearableSizeSystemIT'),
'AlbumRelease': ('AlbumRelease', 'pydantic_schemaorg.AlbumRelease', 'AlbumRelease'),
'EnergyStarCertified': ('EnergyStarCertified', 'pydantic_schemaorg.EnergyStarCertified', 'EnergyStarCertified'),
'ReservationPackage': ('ReservationPackage', 'pydantic_schemaorg.ReservationPackage', 'ReservationPackage'),
'BodyMeasurementNeck': ('BodyMeasurementNeck', 'pydantic_schemaorg.BodyMeasurementNeck', 'BodyMeasurementNeck'),
'GeoShape': ('GeoShape', 'pydantic_schemaorg.GeoShape', 'GeoShape'),
'GeoCircle': ('GeoCircle', 'pydantic_schemaorg.GeoCircle', 'GeoCircle'),
'Consortium': ('Consortium', 'pydantic_schemaorg.Consortium', 'Consortium'),
'WarrantyPromise': ('WarrantyPromise', 'pydantic_schemaorg.WarrantyPromise', 'WarrantyPromise'),
'SocialEvent': ('SocialEvent', 'pydantic_schemaorg.SocialEvent', 'SocialEvent'),
'HighSchool': ('HighSchool', 'pydantic_schemaorg.HighSchool', 'HighSchool'),
'Museum': ('Museum', 'pydantic_schemaorg.Museum', 'Museum'),
'Date': ('Date', 'pydantic_schemaorg.Date', 'Date'),
'BrokerageAccount': ('BrokerageAccount', 'pydantic_schemaorg.BrokerageAccount', 'BrokerageAccount'),
'CheckoutPage': ('CheckoutPage', 'pydantic_schemaorg.CheckoutPage', 'CheckoutPage'),
'LoseAction': ('LoseAction', 'pydantic_schemaorg.LoseAction', 'LoseAction'),
'AnatomicalSystem': ('AnatomicalSystem', 'pydantic_schemaorg.AnatomicalSystem', 'AnatomicalSystem'),
'LowFatDiet': ('LowFatDiet', 'pydantic_schemaorg.LowFatDiet', 'LowFatDiet'),
'SpreadsheetDigitalDocument': ('SpreadsheetDigitalDocument', 'pydantic_schemaorg.SpreadsheetDigitalDocument', 'SpreadsheetDigitalDocument'),
'ZoneBoardingPolicy': ('ZoneBoardingPolicy', 'pydantic_schemaorg.ZoneBoardingPolicy', 'ZoneBoardingPolicy'),
'Nonprofit501e': ('Nonprofit501e', 'pydantic_schemaorg.Nonprofit501e', 'Nonprofit501e'),
'ToyStore': ('ToyStore', 'pydantic_schemaorg.ToyStore', 'ToyStore'),
'IgnoreAction': ('IgnoreAction', 'pydantic_schemaorg.IgnoreAction', 'IgnoreAction'),
'HowOrWhereHealthAspect': ('HowOrWhereHealthAspect', 'pydantic_schemaorg.HowOrWhereHealthAspect', 'HowOrWhereHealthAspect'),
'OfferCatalog': ('OfferCatalog', 'pydantic_schemaorg.OfferCatalog', 'OfferCatalog'),
'EUEnergyEfficiencyCategoryC': ('EUEnergyEfficiencyCategoryC', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryC', 'EUEnergyEfficiencyCategoryC'),
'SubscribeAction': ('SubscribeAction', 'pydantic_schemaorg.SubscribeAction', 'SubscribeAction'),
'CrossSectional': ('CrossSectional', 'pydantic_schemaorg.CrossSectional', 'CrossSectional'),
'PathologyTest': ('PathologyTest', 'pydantic_schemaorg.PathologyTest', 'PathologyTest'),
'WearableSizeSystemFR': ('WearableSizeSystemFR', 'pydantic_schemaorg.WearableSizeSystemFR', 'WearableSizeSystemFR'),
'WearableSizeGroupPetite': ('WearableSizeGroupPetite', 'pydantic_schemaorg.WearableSizeGroupPetite', 'WearableSizeGroupPetite'),
'WearableSizeGroupMisses': ('WearableSizeGroupMisses', 'pydantic_schemaorg.WearableSizeGroupMisses', 'WearableSizeGroupMisses'),
'Mountain': ('Mountain', 'pydantic_schemaorg.Mountain', 'Mountain'),
'RentalVehicleUsage': ('RentalVehicleUsage', 'pydantic_schemaorg.RentalVehicleUsage', 'RentalVehicleUsage'),
'TechArticle': ('TechArticle', 'pydantic_schemaorg.TechArticle', 'TechArticle'),
'APIReference': ('APIReference', 'pydantic_schemaorg.APIReference', 'APIReference'),
'Nonprofit501c7': ('Nonprofit501c7', 'pydantic_schemaorg.Nonprofit501c7', 'Nonprofit501c7'),
'LandmarksOrHistoricalBuildings': ('LandmarksOrHistoricalBuildings', 'pydantic_schemaorg.LandmarksOrHistoricalBuildings', 'LandmarksOrHistoricalBuildings'),
'Diet': ('Diet', 'pydantic_schemaorg.Diet', 'Diet'),
'CableOrSatelliteService': ('CableOrSatelliteService', 'pydantic_schemaorg.CableOrSatelliteService', 'CableOrSatelliteService'),
'BusStop': ('BusStop', 'pydantic_schemaorg.BusStop', 'BusStop'),
'Cemetery': ('Cemetery', 'pydantic_schemaorg.Cemetery', 'Cemetery'),
'BusinessEvent': ('BusinessEvent', 'pydantic_schemaorg.BusinessEvent', 'BusinessEvent'),
'CookAction': ('CookAction', 'pydantic_schemaorg.CookAction', 'CookAction'),
'RemixAlbum': ('RemixAlbum', 'pydantic_schemaorg.RemixAlbum', 'RemixAlbum'),
'Nonprofit501c21': ('Nonprofit501c21', 'pydantic_schemaorg.Nonprofit501c21', 'Nonprofit501c21'),
'Recipe': ('Recipe', 'pydantic_schemaorg.Recipe', 'Recipe'),
'MedicalGuidelineContraindication': ('MedicalGuidelineContraindication', 'pydantic_schemaorg.MedicalGuidelineContraindication', 'MedicalGuidelineContraindication'),
'OriginalShippingFees': ('OriginalShippingFees', 'pydantic_schemaorg.OriginalShippingFees', 'OriginalShippingFees'),
'Nonprofit501c27': ('Nonprofit501c27', 'pydantic_schemaorg.Nonprofit501c27', 'Nonprofit501c27'),
'Menu': ('Menu', 'pydantic_schemaorg.Menu', 'Menu'),
'LowSaltDiet': ('LowSaltDiet', 'pydantic_schemaorg.LowSaltDiet', 'LowSaltDiet'),
'ElementarySchool': ('ElementarySchool', 'pydantic_schemaorg.ElementarySchool', 'ElementarySchool'),
'ParentAudience': ('ParentAudience', 'pydantic_schemaorg.ParentAudience', 'ParentAudience'),
'Fungus': ('Fungus', 'pydantic_schemaorg.Fungus', 'Fungus'),
'Courthouse': ('Courthouse', 'pydantic_schemaorg.Courthouse', 'Courthouse'),
'RearWheelDriveConfiguration': ('RearWheelDriveConfiguration', 'pydantic_schemaorg.RearWheelDriveConfiguration', 'RearWheelDriveConfiguration'),
'RadioSeason': ('RadioSeason', 'pydantic_schemaorg.RadioSeason', 'RadioSeason'),
'Nonprofit501c24': ('Nonprofit501c24', 'pydantic_schemaorg.Nonprofit501c24', 'Nonprofit501c24'),
'OrderDelivered': ('OrderDelivered', 'pydantic_schemaorg.OrderDelivered', 'OrderDelivered'),
'AboutPage': ('AboutPage', 'pydantic_schemaorg.AboutPage', 'AboutPage'),
'DrugStrength': ('DrugStrength', 'pydantic_schemaorg.DrugStrength', 'DrugStrength'),
'Aquarium': ('Aquarium', 'pydantic_schemaorg.Aquarium', 'Aquarium'),
'Library': ('Library', 'pydantic_schemaorg.Library', 'Library'),
'Taxi': ('Taxi', 'pydantic_schemaorg.Taxi', 'Taxi'),
'CheckInAction': ('CheckInAction', 'pydantic_schemaorg.CheckInAction', 'CheckInAction'),
'Artery': ('Artery', 'pydantic_schemaorg.Artery', 'Artery'),
'Conversation': ('Conversation', 'pydantic_schemaorg.Conversation', 'Conversation'),
'InvestmentFund': ('InvestmentFund', 'pydantic_schemaorg.InvestmentFund', 'InvestmentFund'),
'AdvertiserContentArticle': ('AdvertiserContentArticle', 'pydantic_schemaorg.AdvertiserContentArticle', 'AdvertiserContentArticle'),
'TransformedContent': ('TransformedContent', 'pydantic_schemaorg.TransformedContent', 'TransformedContent'),
'Answer': ('Answer', 'pydantic_schemaorg.Answer', 'Answer'),
'DietarySupplement': ('DietarySupplement', 'pydantic_schemaorg.DietarySupplement', 'DietarySupplement'),
'OrderPaymentDue': ('OrderPaymentDue', 'pydantic_schemaorg.OrderPaymentDue', 'OrderPaymentDue'),
'Friday': ('Friday', 'pydantic_schemaorg.Friday', 'Friday'),
'Genetic': ('Genetic', 'pydantic_schemaorg.Genetic', 'Genetic'),
'Corporation': ('Corporation', 'pydantic_schemaorg.Corporation', 'Corporation'),
'CommentPermission': ('CommentPermission', 'pydantic_schemaorg.CommentPermission', 'CommentPermission'),
'GovernmentOrganization': ('GovernmentOrganization', 'pydantic_schemaorg.GovernmentOrganization', 'GovernmentOrganization'),
'BroadcastEvent': ('BroadcastEvent', 'pydantic_schemaorg.BroadcastEvent', 'BroadcastEvent'),
'StagedContent': ('StagedContent', 'pydantic_schemaorg.StagedContent', 'StagedContent'),
'TollFree': ('TollFree', 'pydantic_schemaorg.TollFree', 'TollFree'),
'PaymentAutomaticallyApplied': ('PaymentAutomaticallyApplied', 'pydantic_schemaorg.PaymentAutomaticallyApplied', 'PaymentAutomaticallyApplied'),
'Canal': ('Canal', 'pydantic_schemaorg.Canal', 'Canal'),
'OpeningHoursSpecification': ('OpeningHoursSpecification', 'pydantic_schemaorg.OpeningHoursSpecification', 'OpeningHoursSpecification'),
'LinkRole': ('LinkRole', 'pydantic_schemaorg.LinkRole', 'LinkRole'),
'PlaceboControlledTrial': ('PlaceboControlledTrial', 'pydantic_schemaorg.PlaceboControlledTrial', 'PlaceboControlledTrial'),
'Appearance': ('Appearance', 'pydantic_schemaorg.Appearance', 'Appearance'),
'EUEnergyEfficiencyCategoryG': ('EUEnergyEfficiencyCategoryG', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryG', 'EUEnergyEfficiencyCategoryG'),
'InstallAction': ('InstallAction', 'pydantic_schemaorg.InstallAction', 'InstallAction'),
'BuyAction': ('BuyAction', 'pydantic_schemaorg.BuyAction', 'BuyAction'),
'OceanBodyOfWater': ('OceanBodyOfWater', 'pydantic_schemaorg.OceanBodyOfWater', 'OceanBodyOfWater'),
'Bone': ('Bone', 'pydantic_schemaorg.Bone', 'Bone'),
'ViewAction': ('ViewAction', 'pydantic_schemaorg.ViewAction', 'ViewAction'),
'PercutaneousProcedure': ('PercutaneousProcedure', 'pydantic_schemaorg.PercutaneousProcedure', 'PercutaneousProcedure'),
'DigitalDocumentPermission': ('DigitalDocumentPermission', 'pydantic_schemaorg.DigitalDocumentPermission', 'DigitalDocumentPermission'),
'WearableSizeGroupTall': ('WearableSizeGroupTall', 'pydantic_schemaorg.WearableSizeGroupTall', 'WearableSizeGroupTall'),
'ClaimReview': ('ClaimReview', 'pydantic_schemaorg.ClaimReview', 'ClaimReview'),
'PerformanceRole': ('PerformanceRole', 'pydantic_schemaorg.PerformanceRole', 'PerformanceRole'),
'InvoicePrice': ('InvoicePrice', 'pydantic_schemaorg.InvoicePrice', 'InvoicePrice'),
'SRP': ('SRP', 'pydantic_schemaorg.SRP', 'SRP'),
'UnRegisterAction': ('UnRegisterAction', 'pydantic_schemaorg.UnRegisterAction', 'UnRegisterAction'),
'InForce': ('InForce', 'pydantic_schemaorg.InForce', 'InForce'),
'FDAnotEvaluated': ('FDAnotEvaluated', 'pydantic_schemaorg.FDAnotEvaluated', 'FDAnotEvaluated'),
'FDAcategoryB': ('FDAcategoryB', 'pydantic_schemaorg.FDAcategoryB', 'FDAcategoryB'),
'HealthTopicContent': ('HealthTopicContent', 'pydantic_schemaorg.HealthTopicContent', 'HealthTopicContent'),
'OrderAction': ('OrderAction', 'pydantic_schemaorg.OrderAction', 'OrderAction'),
'Nonprofit501d': ('Nonprofit501d', 'pydantic_schemaorg.Nonprofit501d', 'Nonprofit501d'),
'WearableSizeGroupWomens': ('WearableSizeGroupWomens', 'pydantic_schemaorg.WearableSizeGroupWomens', 'WearableSizeGroupWomens'),
'Infectious': ('Infectious', 'pydantic_schemaorg.Infectious', 'Infectious'),
'EUEnergyEfficiencyCategoryD': ('EUEnergyEfficiencyCategoryD', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryD', 'EUEnergyEfficiencyCategoryD'),
'Integer': ('Integer', 'pydantic_schemaorg.Integer', 'Integer'),
'OneTimePayments': ('OneTimePayments', 'pydantic_schemaorg.OneTimePayments', 'OneTimePayments'),
'Float': ('Float', 'pydantic_schemaorg.Float', 'Float'),
'ReadAction': ('ReadAction', 'pydantic_schemaorg.ReadAction', 'ReadAction'),
'RelatedTopicsHealthAspect': ('RelatedTopicsHealthAspect', 'pydantic_schemaorg.RelatedTopicsHealthAspect', 'RelatedTopicsHealthAspect'),
'SportsTeam': ('SportsTeam', 'pydantic_schemaorg.SportsTeam', 'SportsTeam'),
'SearchResultsPage': ('SearchResultsPage', 'pydantic_schemaorg.SearchResultsPage', 'SearchResultsPage'),
'Registry': ('Registry', 'pydantic_schemaorg.Registry', 'Registry'),
'CassetteFormat': ('CassetteFormat', 'pydantic_schemaorg.CassetteFormat', 'CassetteFormat'),
'WriteAction': ('WriteAction', 'pydantic_schemaorg.WriteAction', 'WriteAction'),
'PerformAction': ('PerformAction', 'pydantic_schemaorg.PerformAction', 'PerformAction'),
'Dermatology': ('Dermatology', 'pydantic_schemaorg.Dermatology', 'Dermatology'),
'SportsClub': ('SportsClub', 'pydantic_schemaorg.SportsClub', 'SportsClub'),
'WebAPI': ('WebAPI', 'pydantic_schemaorg.WebAPI', 'WebAPI'),
'FreeReturn': ('FreeReturn', 'pydantic_schemaorg.FreeReturn', 'FreeReturn'),
'NoninvasiveProcedure': ('NoninvasiveProcedure', 'pydantic_schemaorg.NoninvasiveProcedure', 'NoninvasiveProcedure'),
'HomeGoodsStore': ('HomeGoodsStore', 'pydantic_schemaorg.HomeGoodsStore', 'HomeGoodsStore'),
'EatAction': ('EatAction', 'pydantic_schemaorg.EatAction', 'EatAction'),
'Hotel': ('Hotel', 'pydantic_schemaorg.Hotel', 'Hotel'),
'MoneyTransfer': ('MoneyTransfer', 'pydantic_schemaorg.MoneyTransfer', 'MoneyTransfer'),
'Code': ('Code', 'pydantic_schemaorg.Code', 'Code'),
'ImagingTest': ('ImagingTest', 'pydantic_schemaorg.ImagingTest', 'ImagingTest'),
'Map': ('Map', 'pydantic_schemaorg.Map', 'Map'),
'Play': ('Play', 'pydantic_schemaorg.Play', 'Play'),
'WearableSizeSystemMX': ('WearableSizeSystemMX', 'pydantic_schemaorg.WearableSizeSystemMX', 'WearableSizeSystemMX'),
'TypesHealthAspect': ('TypesHealthAspect', 'pydantic_schemaorg.TypesHealthAspect', 'TypesHealthAspect'),
'FoodService': ('FoodService', 'pydantic_schemaorg.FoodService', 'FoodService'),
'GovernmentPermit': ('GovernmentPermit', 'pydantic_schemaorg.GovernmentPermit', 'GovernmentPermit'),
'OfferForPurchase': ('OfferForPurchase', 'pydantic_schemaorg.OfferForPurchase', 'OfferForPurchase'),
'WearableSizeSystemGS1': ('WearableSizeSystemGS1', 'pydantic_schemaorg.WearableSizeSystemGS1', 'WearableSizeSystemGS1'),
'Reservoir': ('Reservoir', 'pydantic_schemaorg.Reservoir', 'Reservoir'),
'HealthPlanFormulary': ('HealthPlanFormulary', 'pydantic_schemaorg.HealthPlanFormulary', 'HealthPlanFormulary'),
'FollowAction': ('FollowAction', 'pydantic_schemaorg.FollowAction', 'FollowAction'),
'TouristTrip': ('TouristTrip', 'pydantic_schemaorg.TouristTrip', 'TouristTrip'),
'TVEpisode': ('TVEpisode', 'pydantic_schemaorg.TVEpisode', 'TVEpisode'),
'SoldOut': ('SoldOut', 'pydantic_schemaorg.SoldOut', 'SoldOut'),
'Waterfall': ('Waterfall', 'pydantic_schemaorg.Waterfall', 'Waterfall'),
'MovingCompany': ('MovingCompany', 'pydantic_schemaorg.MovingCompany', 'MovingCompany'),
'ReservationPending': ('ReservationPending', 'pydantic_schemaorg.ReservationPending', 'ReservationPending'),
'ApartmentComplex': ('ApartmentComplex', 'pydantic_schemaorg.ApartmentComplex', 'ApartmentComplex'),
'Suspended': ('Suspended', 'pydantic_schemaorg.Suspended', 'Suspended'),
'EBook': ('EBook', 'pydantic_schemaorg.EBook', 'EBook'),
'Florist': ('Florist', 'pydantic_schemaorg.Florist', 'Florist'),
'Psychiatric': ('Psychiatric', 'pydantic_schemaorg.Psychiatric', 'Psychiatric'),
'MaximumDoseSchedule': ('MaximumDoseSchedule', 'pydantic_schemaorg.MaximumDoseSchedule', 'MaximumDoseSchedule'),
'Virus': ('Virus', 'pydantic_schemaorg.Virus', 'Virus'),
'EventMovedOnline': ('EventMovedOnline', 'pydantic_schemaorg.EventMovedOnline', 'EventMovedOnline'),
'MovieTheater': ('MovieTheater', 'pydantic_schemaorg.MovieTheater', 'MovieTheater'),
'TelevisionChannel': ('TelevisionChannel', 'pydantic_schemaorg.TelevisionChannel', 'TelevisionChannel'),
'EntryPoint': ('EntryPoint', 'pydantic_schemaorg.EntryPoint', 'EntryPoint'),
'Paperback': ('Paperback', 'pydantic_schemaorg.Paperback', 'Paperback'),
'PreventionIndication': ('PreventionIndication', 'pydantic_schemaorg.PreventionIndication', 'PreventionIndication'),
'GolfCourse': ('GolfCourse', 'pydantic_schemaorg.GolfCourse', 'GolfCourse'),
'BusinessFunction': ('BusinessFunction', 'pydantic_schemaorg.BusinessFunction', 'BusinessFunction'),
'OrderCancelled': ('OrderCancelled', 'pydantic_schemaorg.OrderCancelled', 'OrderCancelled'),
'Schedule': ('Schedule', 'pydantic_schemaorg.Schedule', 'Schedule'),
'Ear': ('Ear', 'pydantic_schemaorg.Ear', 'Ear'),
'CharitableIncorporatedOrganization': ('CharitableIncorporatedOrganization', 'pydantic_schemaorg.CharitableIncorporatedOrganization', 'CharitableIncorporatedOrganization'),
'Volcano': ('Volcano', 'pydantic_schemaorg.Volcano', 'Volcano'),
'DeliveryEvent': ('DeliveryEvent', 'pydantic_schemaorg.DeliveryEvent', 'DeliveryEvent'),
'HowToStep': ('HowToStep', 'pydantic_schemaorg.HowToStep', 'HowToStep'),
'RightHandDriving': ('RightHandDriving', 'pydantic_schemaorg.RightHandDriving', 'RightHandDriving'),
'BodyMeasurementUnderbust': ('BodyMeasurementUnderbust', 'pydantic_schemaorg.BodyMeasurementUnderbust', 'BodyMeasurementUnderbust'),
'UserDownloads': ('UserDownloads', 'pydantic_schemaorg.UserDownloads', 'UserDownloads'),
'BasicIncome': ('BasicIncome', 'pydantic_schemaorg.BasicIncome', 'BasicIncome'),
'RsvpAction': ('RsvpAction', 'pydantic_schemaorg.RsvpAction', 'RsvpAction'),
'AllWheelDriveConfiguration': ('AllWheelDriveConfiguration', 'pydantic_schemaorg.AllWheelDriveConfiguration', 'AllWheelDriveConfiguration'),
'MonetaryAmount': ('MonetaryAmount', 'pydantic_schemaorg.MonetaryAmount', 'MonetaryAmount'),
'RefurbishedCondition': ('RefurbishedCondition', 'pydantic_schemaorg.RefurbishedCondition', 'RefurbishedCondition'),
'NailSalon': ('NailSalon', 'pydantic_schemaorg.NailSalon', 'NailSalon'),
'Gene': ('Gene', 'pydantic_schemaorg.Gene', 'Gene'),
'ParcelDelivery': ('ParcelDelivery', 'pydantic_schemaorg.ParcelDelivery', 'ParcelDelivery'),
'RsvpResponseMaybe': ('RsvpResponseMaybe', 'pydantic_schemaorg.RsvpResponseMaybe', 'RsvpResponseMaybe'),
'ImageObjectSnapshot': ('ImageObjectSnapshot', 'pydantic_schemaorg.ImageObjectSnapshot', 'ImageObjectSnapshot'),
'LibrarySystem': ('LibrarySystem', 'pydantic_schemaorg.LibrarySystem', 'LibrarySystem'),
'True_': ('True_', 'pydantic_schemaorg.True_', 'True_'),
'PaymentChargeSpecification': ('PaymentChargeSpecification', 'pydantic_schemaorg.PaymentChargeSpecification', 'PaymentChargeSpecification'),
'SportsEvent': ('SportsEvent', 'pydantic_schemaorg.SportsEvent', 'SportsEvent'),
'ReserveAction': ('ReserveAction', 'pydantic_schemaorg.ReserveAction', 'ReserveAction'),
'Playground': ('Playground', 'pydantic_schemaorg.Playground', 'Playground'),
'Casino': ('Casino', 'pydantic_schemaorg.Casino', 'Casino'),
'GameServer': ('GameServer', 'pydantic_schemaorg.GameServer', 'GameServer'),
'UKTrust': ('UKTrust', 'pydantic_schemaorg.UKTrust', 'UKTrust'),
'Observational': ('Observational', 'pydantic_schemaorg.Observational', 'Observational'),
'GatedResidenceCommunity': ('GatedResidenceCommunity', 'pydantic_schemaorg.GatedResidenceCommunity', 'GatedResidenceCommunity'),
'ParkingMap': ('ParkingMap', 'pydantic_schemaorg.ParkingMap', 'ParkingMap'),
'Seat': ('Seat', 'pydantic_schemaorg.Seat', 'Seat'),
'Therapeutic': ('Therapeutic', 'pydantic_schemaorg.Therapeutic', 'Therapeutic'),
'ComedyEvent': ('ComedyEvent', 'pydantic_schemaorg.ComedyEvent', 'ComedyEvent'),
'Nonprofit501c14': ('Nonprofit501c14', 'pydantic_schemaorg.Nonprofit501c14', 'Nonprofit501c14'),
'EUEnergyEfficiencyCategoryA': ('EUEnergyEfficiencyCategoryA', 'pydantic_schemaorg.EUEnergyEfficiencyCategoryA', 'EUEnergyEfficiencyCategoryA'),
'SingleBlindedTrial': ('SingleBlindedTrial', 'pydantic_schemaorg.SingleBlindedTrial', 'SingleBlindedTrial'),
'EventScheduled': ('EventScheduled', 'pydantic_schemaorg.EventScheduled', 'EventScheduled'),
'GovernmentService': ('GovernmentService', 'pydantic_schemaorg.GovernmentService', 'GovernmentService'),
'Bridge': ('Bridge', 'pydantic_schemaorg.Bridge', 'Bridge'),
'Oncologic': ('Oncologic', 'pydantic_schemaorg.Oncologic', 'Oncologic'),
'UserComments': ('UserComments', 'pydantic_schemaorg.UserComments', 'UserComments'),
'PhotographAction': ('PhotographAction', 'pydantic_schemaorg.PhotographAction', 'PhotographAction'),
'MinimumAdvertisedPrice': ('MinimumAdvertisedPrice', 'pydantic_schemaorg.MinimumAdvertisedPrice', 'MinimumAdvertisedPrice'),
'OfficeEquipmentStore': ('OfficeEquipmentStore', 'pydantic_schemaorg.OfficeEquipmentStore', 'OfficeEquipmentStore'),
'ProductCollection': ('ProductCollection', 'pydantic_schemaorg.ProductCollection', 'ProductCollection'),
'ActivateAction': ('ActivateAction', 'pydantic_schemaorg.ActivateAction', 'ActivateAction'),
'EvidenceLevelA': ('EvidenceLevelA', 'pydantic_schemaorg.EvidenceLevelA', 'EvidenceLevelA'),
'CompoundPriceSpecification': ('CompoundPriceSpecification', 'pydantic_schemaorg.CompoundPriceSpecification', 'CompoundPriceSpecification'),
'_3DModel': ('_3DModel', 'pydantic_schemaorg._3DModel', '_3DModel'),
'MedicalTrial': ('MedicalTrial', 'pydantic_schemaorg.MedicalTrial', 'MedicalTrial'),
'Throat': ('Throat', 'pydantic_schemaorg.Throat', 'Throat'),
}